import React, { useState, useContext, useEffect } from "react";
import { Col, Row, Media, Button, Spinner, Container } from "reactstrap";

import { gql } from "@apollo/client";
import FilterContext from "../helpers/filter/FilterContext";
import ProductItem from "./common/product-box/ProductBox1";
import { CurrencyContext } from "../helpers/Currency/CurrencyContext";
import { useRouter } from "next/router";
import PostLoader from "./common/PostLoader";
import CartContext from "../helpers/cart";
import errorHandler from "../utils/errorHandler";
import jwtAxios from "../utils/Apis";
import { Empty, Spin } from "antd";

const ProductList = ({
  subCatPath = `product/allProducts`,
  name,
  clickRoute,
  colClass,
  layoutList,
}) => {
  const [grid, setGrid] = useState(colClass);
  const [layout, setLayout] = useState(layoutList);
  const [data, setData] = useState(null);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(subCatPath);
        setData(response.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };
    fetchData();
  }, []);
  return (
    <>
      {isLoading ? (
        <Container style={{ marginBottom: "100px" }}>
          <Row style={{ justifyContent: "center" }}>
            <Spin size="large" />
          </Row>
        </Container>
      ) : (
        <Col className="collection-content" style={{ background: "#F4F4F4" }}>
          <div className="page-main-content">
            <Row>
              <Col sm="12" style={{ padding: "40px" }}>
                <div className="top-banner-title">
                  {/* <div className="top-banner-content small-section"> */}
                  <h4> {name ? name : "Popular Genuine Accessories"}</h4>
                  {/* </div> */}
                </div>

                <div className="collection-product-wrapper ">
                  {!data || data.length === 0 || isLoading ? (
                    <div className="row mx-0 margin-default mt-4">
                      <div className="col-xl-3 col-lg-4 col-6">
                        <PostLoader />
                      </div>
                      <div className="col-xl-3 col-lg-4 col-6">
                        <PostLoader />
                      </div>
                      <div className="col-xl-3 col-lg-4 col-6">
                        <PostLoader />
                      </div>
                      <div className="col-xl-3 col-lg-4 col-6">
                        <PostLoader />
                      </div>
                    </div>
                  ) : (
                    <>
                      <div className={`product-wrapper-grid ${layout}`}>
                        <Row>
                          {data &&
                            data?.map((product, i) => (
                              <div className={grid} key={i}>
                                <div className="product">
                                  <div>
                                    <ProductItem
                                      clickRoute={
                                        clickRoute
                                          ? `/sub-categories/${product.id}`
                                          : `/product-details/${product.id}`
                                      }
                                      des={true}
                                      product={product}
                                      cartClass="cart-info cart-wrap"
                                    />
                                  </div>
                                </div>
                              </div>
                            ))}
                        </Row>
                      </div>
                    </>
                  )}
                </div>
              </Col>
            </Row>
          </div>
        </Col>
      )}
    </>
  );
};

export default ProductList;
