import React, { useContext, useEffect, useState } from "react";
import { Checkbox, Form, Input, Select } from "antd";
import PhoneCodes from "./constant/Codes";

const AddressForm = ({ form }) => {
     const [useSameAsShipping, setUseSameAsShipping] = useState(true);

     const handleCheckboxChange = (e) => {
       setUseSameAsShipping(e.target.checked);
     };
  return (
    <>
      <div className="checkout-title">
        <h3>Shipping Details</h3>
      </div>
      <div className="row check-out">
        <div className="form-group col-md-12 col-sm-12 col-xs-12">
          <Form.Item
            label={"Country"}
            name="country"
            rules={[
              {
                required: true,
                message: "Country name is required",
              },
            ]}
            initialValue={"United States"}
          >
            <Select
              className="custom-select"
              showSearch
              placeholder={"Select your country"}
              optionFilterProp="children"
              filterOption={(input, option) =>
                option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
              }
            >
              {PhoneCodes?.map((country) => (
                <Select.Option key={country.code} value={country.name}>
                  {country.name}
                </Select.Option>
              ))}
            </Select>
          </Form.Item>
        </div>
        <div className="form-group col-md-6 col-sm-6 col-xs-12">
          <Form.Item
            name="first_name"
            label="First Name"
            rules={[
              {
                required: true,
                message: "Please input your first name!",
              },
            ]}
          >
            <Input placeholder="First Name" style={{ borderRadius: "0px" }} />
          </Form.Item>
        </div>
        <div className="form-group col-md-6 col-sm-6 col-xs-12">
          <Form.Item
            name="last_name"
            label=" Last Name"
            rules={[
              {
                required: true,
                message: "Please input your last name!",
              },
            ]}
          >
            <Input placeholder="Last Name" style={{ borderRadius: "0px" }} />
          </Form.Item>
        </div>
        <div className="form-group col-md-12 col-sm-12 col-xs-12">
          <Form.Item name="company" label="Company">
            <Input
              placeholder="Company (optional)"
              style={{ borderRadius: "0px" }}
            />
          </Form.Item>
        </div>
        <div className="form-group col-md-6 col-sm-6 col-xs-12">
          <Form.Item
            rules={[
              {
                required: true,
                message: "Please input zip code!",
              },
            ]}
            name="zip_code"
            label="Zip Code"
          >
            <Input placeholder="Zip Code" style={{ borderRadius: "0px" }} />
          </Form.Item>
        </div>
        <div className="form-group col-md-6 col-sm-6 col-xs-12 ">
          <Form.Item
            rules={[
              {
                required: true,
                message: "Please input your phone!",
              },
            ]}
            name="phone"
            label="Phone"
          >
            <Input placeholder="phone" style={{ borderRadius: "0px" }} />
          </Form.Item>
        </div>
        <div className="form-group col-md-6 col-sm-6 col-xs-12">
          <Form.Item
            rules={[
              {
                required: true,
                message: "Please input your City!",
              },
            ]}
            name="city"
            label="City"
          >
            <Input placeholder="City" style={{ borderRadius: "0px" }} />
          </Form.Item>
        </div>
        <div className="form-group col-md-6 col-sm-6 col-xs-12">
          <Form.Item
            rules={[
              {
                required: true,
                message: "Please input your State!",
              },
            ]}
            name="state"
            label="State"
          >
            <Input placeholder="State" style={{ borderRadius: "0px" }} />
          </Form.Item>
        </div>

        <div className="form-group col-md-12 col-sm-12 col-xs-12">
          <Form.Item
            rules={[
              {
                required: true,
                message: "Please input your phone!",
              },
            ]}
            name="address_1"
            label="Address line 1"
          >
            <Input placeholder="address" style={{ borderRadius: "0px" }} />
          </Form.Item>
        </div>
        <div className="form-group col-md-12 col-sm-12 col-xs-12">
          <Form.Item name="address_2" label="Address line 2">
            <Input
              placeholder="appartment/site/bulding (optional)"
              style={{ borderRadius: "0px" }}
            />
          </Form.Item>
        </div>

        <div className="form-group col-md-12 col-sm-12 col-xs-12">
          <Form.Item name="addressTitle" label="Save address as (optional)">
            <Input
              placeholder="Save address as"
              style={{ borderRadius: "0px" }}
            />
          </Form.Item>
        </div>
        <Form.Item name="save_as">
          <Checkbox>Save as my default address</Checkbox>
        </Form.Item>
      </div>

      <div className="checkout-title">
        <h3>Billing Details</h3>
      </div>
      <div className="row check-out">
        <Form.Item name="useSameAsShipping">
          <Checkbox defaultChecked onChange={handleCheckboxChange}>
            Use the same information as shipping
          </Checkbox>
        </Form.Item>

        {!useSameAsShipping && (
          <>
            <div className="row check-out">
              <div className="form-group col-md-6 col-sm-6 col-xs-12">
                <Form.Item
                  rules={[
                    {
                      required: true,
                      message: "Please input zip code!",
                    },
                  ]}
                  name="billing_zip_code"
                  label="Zip Code"
                >
                  <Input
                    placeholder="Zip Code"
                    style={{ borderRadius: "0px" }}
                  />
                </Form.Item>
              </div>
              <div className="form-group col-md-6 col-sm-6 col-xs-12">
                <Form.Item
                  rules={[
                    {
                      required: true,
                      message: "Please input your City!",
                    },
                  ]}
                  name="billing_city"
                  label="City"
                >
                  <Input
                    placeholder="City"
                    style={{ borderRadius: "0px" }}
                  />
                </Form.Item>
              </div>

              <div className="form-group col-md-6 col-sm-6 col-xs-12">
                <Form.Item
                  rules={[
                    {
                      required: true,
                      message: "Please input your State!",
                    },
                  ]}
                  name="billing_state"
                  label="State"
                >
                  <Input
                    placeholder="State"
                    style={{ borderRadius: "0px" }}
                  />
                </Form.Item>
              </div>

              <div className="form-group col-md-12 col-sm-12 col-xs-12">
                <Form.Item
                  rules={[
                    {
                      required: true,
                      message: "Please input your phone!",
                    },
                  ]}
                  name="billing_address_1"
                  label="Address line 1"
                >
                  <Input
                    placeholder="address"
                    style={{ borderRadius: "0px" }}
                  />
                </Form.Item>
              </div>
              <div className="form-group col-md-12 col-sm-12 col-xs-12">
                <Form.Item name="billing_address_2" label="Address line 2">
                  <Input
                    placeholder="appartment/site/bulding (optional)"
                    style={{ borderRadius: "0px" }}
                  />
                </Form.Item>
              </div>
            </div>
          </>
        )}
      </div>
    </>
  );
};

export default AddressForm;
