import { Button, notification } from "antd";
import React, { useContext, useEffect, useState } from "react";
import { Col, Container, Row, Tooltip } from "reactstrap";
import FaqList from "./FaqList";
import AskQuestion from "./AskQuestion";
import { UserContext } from "../helpers/loginContext/loginContext";
import jwtAxios from "../utils/Apis";

const CustomerQA = ({ productId }) => {
  const { user } = useContext(UserContext);
  const [tooltipOpen, setTooltipOpen] = useState(false);
  const [quOpen, setQuOpen] = useState(false);
  const [data, setData] = useState([]);
  const [loading, setLoading] = useState(false);

  const fetchData = async () => {
    try {
      const response = await jwtAxios.get(`get/qa/${productId}`);
      console.log(response, "response");
      setData(response.data);
    } catch (error) {
      errorHandler(error);
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchData();
  }, [productId]);
  const toggleQues = () => {
    if (user.id) setQuOpen(!tooltipOpen);
    else
      notification.info({
        message: `Login required`,
        description: "Please login first to ask a question!",
        placement: "bottomRight",
      });
  };
  const faqData = [
    {
      qus: "Q: I would like to know availability and if it is direct fit replacement",
      ans: "A: You can Select Your Vehicle from Garage to check if this part fits your vehicle.",
    },
  ];
  return (
    <div>
      <Container style={{ marginBottom: "100px" }}>
        <section className="blog-detail-page review-page">
          <Row>
            <Col sm="9">
              <h4 className="qatitle">Customer Questions & Answers</h4>
              <hr />
              <Col sm="12">
                <div
                  className="accordion theme-accordion"
                  id="accordionExample"
                >
                  {data?.length > 0
                    ? data.map((thisqa, i) => (
                        <>
                          <h4 className="qaquestion">Q: {thisqa.question}</h4>

                          <p className="qaposted">
                            Posted by{" "}
                            {`${thisqa.user.first_name} ${
                              thisqa?.user?.last_name || ""
                            }`}
                          </p>
                          <h6 className="qaanswer">
                            <strong> A:</strong> {thisqa.answer || "Pending"}
                          </h6>
                          <p className="qaposted2">
                            {thisqa.answer &&
                              "Posted by ToyotaPartsDeal Specialist"}
                          </p>
                        </>
                      ))
                    : faqData.map((faq, i) => (
                        <>
                          <h4 className="qaquestion">
                            Q: I would like to know availability and if it is
                            direct fit replacement
                          </h4>

                          <p className="qaposted">
                            Posted by ToyotaPartsDeal Specialist
                          </p>
                          <h6 className="qaanswer">
                            <strong> A:</strong> You can Select Your Vehicle to
                            check if this part fits your vehicle.
                          </h6>
                          <p className="qaposted2">
                            Posted by ToyotaPartsDeal Specialist
                          </p>
                        </>
                      ))}
                </div>
                <hr />
              </Col>
            </Col>
          </Row>
          <Col sm="9">
            {quOpen ? (
              <AskQuestion
                toggleQues={setQuOpen}
                productId={productId}
                user={user}
              />
            ) : (
              <p>
                If you have any questions about this product, please don't
                hesitate to ask us. We will be happy to help you!
              </p>
            )}
            {!quOpen && (
              <Button
                className="btn btn-solid cautionbtn2"
                onClick={toggleQues}
                style={{
                  display:"flex",
                  alignItems:"center"
                  //  paddingBottom: "30px" 
              }}
              >
                Ask a question
              </Button>
            )}
          </Col>
        </section>
      </Container>
    </div>
  );
};

export default CustomerQA;
