import React, { useContext, useEffect, useState } from "react";
// import two from "../../public/assets/images/2.jpg";
// import avtar from "../../public/assets/images/avtar.jpg";
// import twenty from "../../public/assets/images/20.jpg";
import { Container, Row, Col, Media, Tooltip } from "reactstrap";
import Slider from "react-slick";
import { Slider3 } from "../services/script";
import jwtAxios from "../utils/Apis";
import errorHandler from "../utils/errorHandler";
import { UserContext } from "../helpers/loginContext/loginContext";
import { Button } from "antd";

const ReviewContent = [
  {
    img: "/assets/images/avtar.jpg",
    name: "Mark Jecno",
    datetime: "12 Jannuary 2023 at 1:30AM",
    review:
      "Donec rhoncus massa quis nibh imperdiet dictum. Vestibulum id est sit amet felis fringilla bibendum at at leo.",
    likes: "14",
    dislikes: "2",
    color: "#90C643",
  },
  {
    img: "/assets/images/2.jpg",
    name: "Mark Jecno",
    datetime: "12 Jannuary 2023 at 1:30AM",
    review:
      "Donec rhoncus massa quis nibh imperdiet dictum. Vestibulum id est sit amet felis fringilla bibendum at at leo.",
    likes: "14",
    dislikes: "2",
    color: "#F1C40F",
  },
  {
    img: "/assets/images/20.jpg",
    name: "Mark Jecno",
    datetime: "12 Jannuary 2023 at 1:30AM",
    review:
      "Donec rhoncus massa quis nibh imperdiet dictum. Vestibulum id est sit amet felis fringilla bibendum at at leo.",
    likes: "14",
    dislikes: "2",
    color: "#E74C3C",
  },
  {
    img: "/assets/images/avtar.jpg",
    name: "Mark Jecno",
    datetime: "12 Jannuary 2023 at 1:30AM",
    review:
      "Donec rhoncus massa quis nibh imperdiet dictum. Vestibulum id est sit amet felis fringilla bibendum at at leo.",
    likes: "14",
    dislikes: "2",
    color: "#27BFFF",
  },
  {
    img: "/assets/images/2.jpg",
    name: "Mark Jecno",
    datetime: "12 Jannuary 2023 at 1:30AM",
    review:
      "Donec rhoncus massa quis nibh imperdiet dictum. Vestibulum id est sit amet felis fringilla bibendum at at leo.",
    likes: "14",
    dislikes: "2",
    color: "#91278F",
  },
];

const MasterReview = ({
  user,
  id,
  name,
  datetime,
  review,
  likes,
  dislikes,
}) => {
  let RatingStars = [];
  let rating = 5;
  for (var i = 0; i < rating; i++) {
    RatingStars.push(<i className="fa fa-star" key={i}></i>);
  }
  const [likeCount, setLikeCount] = useState(Number(likes));
  const [dislikeCount, setDislikeCount] = useState(Number(dislikes));
  const [isLikeClicked, setIsLikeClicked] = useState(false);
  const [isDislikeClicked, setIsDislikeClicked] = useState(false);
  const [tooltipOpen, setTooltipOpen] = useState(false);

  const toggle = () => setTooltipOpen(!tooltipOpen);

  const handleLikeClick = async () => {
    try {
      if (!isLikeClicked) {
        // Send Axios request to increase likes on the server
        // const response = await Axios.post("/api/like", {
        //   reviewId: "yourReviewId",
        // });
        const response = await jwtAxios.post(`like/${id}`);

        // Update state with the new like count and set isLikeClicked to true
        setLikeCount(likeCount + 1);
        setIsLikeClicked(true);

        // If dislike was clicked before, reset the dislike state
        if (isDislikeClicked) {
          setDislikeCount(dislikeCount - 1);
          setIsDislikeClicked(false);
        }
      }
    } catch (error) {
      console.error("Error liking the review:", error);
    }
  };

  const handleDislikeClick = async () => {
    try {
      if (!isDislikeClicked) {
        // Send Axios request to increase dislikes on the server
        // const response = await Axios.post("/api/dislike", {
        //   reviewId: "yourReviewId",
        // });
        const response = await jwtAxios.post(`dislike/${id}`);
        // Update state with the new dislike count and set isDislikeClicked to true
        setDislikeCount(dislikeCount + 1);
        setIsDislikeClicked(true);

        // If like was clicked before, reset the like state
        if (isLikeClicked) {
          setLikeCount(likeCount - 1);
          setIsLikeClicked(false);
        }
      }
    } catch (error) {
      console.error("Error disliking the review:", error);
    }
  };

  return (
    <li style={{ borderColor: "grey" }}>
      <div className="media">
        {/* <Media src={img} alt="Generic placeholder image" /> */}
        <div className="media-body">
          <h6>
            {name} <span>({datetime})</span>
          </h6>

          <div className="rating">{RatingStars}</div>

          <p>{review}</p>
          <ul className="comnt-sec">
            <li>
              <Button
                disabled={isLikeClicked || !user?.id}
                type="link"
                onClick={handleLikeClick}
                id="Tooltip-"
              >
                <i className="fa fa-thumbs-o-up" aria-hidden="true"></i>
                <span>({likeCount})</span>
              </Button>
            </li>
            <li>
              <Button
                disabled={isDislikeClicked || !user?.id}
                type="link"
                onClick={handleDislikeClick}
                id="Tooltip-"
              >
                <div className="unlike">
                  <i className="fa fa-thumbs-o-down" aria-hidden="true"></i>
                  <span>({dislikeCount})</span>
                </div>
              </Button>
              {!user?.id && (
                <Tooltip
                  placement={"bottom"}
                  isOpen={tooltipOpen}
                  target={"Tooltip-"}
                  toggle={toggle}
                >
                  {!user?.id ? "Please login to like/dislike" : null}
                </Tooltip>
              )}
            </li>
          </ul>
        </div>
      </div>
    </li>
  );
};

const ReviewSection = () => {
  const { user } = useContext(UserContext);
  const [data, setData] = useState([]);
  const [loading, setLoading] = useState(false);

  const fetchData = async () => {
    try {
      setLoading(true);
      const response = await jwtAxios.get(`comment/getAllcomments`);
      console.log(response, "hdjhfd");
      setData(response.data.data);
      setLoading(false);
    } catch (error) {
      errorHandler(error);
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchData();
  }, []);

  function formatDateTime(dateString) {
    const options = {
      year: "numeric",
      month: "long",
      day: "numeric",
      hour: "numeric",
      minute: "numeric",
    };

    const dateObject = new Date(dateString);
    const formattedDateTime = new Intl.DateTimeFormat("en-US", options).format(
      dateObject
    );

    return `${formattedDateTime}`;
  }
  return (
    <Container style={{ marginBottom: "100px" }}>
      <section
        // className="service small-section pb-0"
        className="blog-detail-page review-page"
      >
        <Row
        // className="partition4"
        >
          <div className="blogslider">
            <Slider
              {...Slider3}
              className="slide-3 no-arrow slick-default-margin blogwidth"
            >
              {data &&
                data?.length > 0 &&
                data.map((review, i) => {
                  return (
                    <Col
                      // lg="3"
                      // xs="6"
                      // className="service-block1"
                      style={{ borderColor: "grey" }}
                      // key={i}
                      sm="4"
                    >
                      <ul
                        className="comment-section"
                        style={{ borderColor: review.color }}
                      >
                        <MasterReview
                          key={i}
                          id={review.id}
                          name={
                            `${review.user?.first_name || "User"} ${
                              review.user?.last_name || ""
                            }` || "User Name"
                          }
                          datetime={formatDateTime(review.created_at)}
                          review={review.comment}
                          likes={review.like}
                          dislikes={review.dislike}
                          user={user}
                        />
                      </ul>
                    </Col>
                  );
                })}
            </Slider>
          </div>
        </Row>
      </section>
    </Container>
  );
};
export default ReviewSection;
