import React, { useContext, useEffect, useState } from "react";
import { PayPalScriptProvider, PayPalButtons } from "@paypal/react-paypal-js";
import { useRouter } from "next/router";
import { Spin } from "antd";
import CartContext from "../helpers/cart";
import { UserContext } from "../helpers/loginContext/loginContext";
import jwtAxios from "../utils/Apis";
const PayPalId =
  "AamsGuXTmR5iwpWsYHIjV0JJdSxJds30AK4mg9hCKVS_xOXxNmfNbzDlTKS28Vy54RZQgebb4AHegpxu";
const getLocalItems = () => {
  try {
    const list = localStorage.getItem("orderData");
    if (list === null) {
      return {};
    } else {
      return JSON.parse(list);
    }
  } catch (err) {
    return {};
  }
};
const Paypal = ({ shipCost }) => {
  const router = useRouter();
  const cartContext = useContext(CartContext);
  const cartItems = cartContext.state;
  const cartTotal = cartContext.cartTotal;
  const { user } = useContext(UserContext);

  const [error, setError] = useState(null);
  const [loading, setLoading] = useState(false);

  const handleSubmit = async (transactionId, payer_id) => {
    try {
      setLoading(true);

      if (error) {
        setError(error.message);
      } else {
        let values = getLocalItems();
        values.payer_id = payer_id;
        values.ship_cost = shipCost;
        values.cart = cartItems;
        values.appartment = "appartment";
        values.sub_total = cartTotal + shipCost;
        if (user) {
          values.user = { id: user.id };
          values.user_id = user.id;
          values.id = user.id;
        }
        // console.log(token, values);
        const response = await jwtAxios.post(
          `paypal/confirm/${transactionId}`,
          values
        );

        const orderId = response?.data?.data?.id;
        if (response.data?.success && orderId) {
          router.push({
            pathname: `/page/order-success/${orderId}`,
          });
        }
        // console.log(token, response);
      }
    } finally {
      setLoading(false);
    }
  };

  return (
    <PayPalScriptProvider
      options={{
        clientId: PayPalId,
      }}
    >
      <PayPalButtons
        createOrder={(data, actions) => {
          return actions.order.create({
            purchase_units: [
              {
                amount: {
                  value: cartTotal+shipCost,
                },
              },
            ],
            application_context: {
              shipping_preference: "NO_SHIPPING",
            },
          });
        }}
        onApprove={(data, actions) => {
          return actions.order.capture().then((details) => {
            console.log(details, "details");
            handleSubmit(details?.id, details?.payer?.payer_id);

            // alert(`Transaction completed by ${details.id}`);
          });
        }}
      />
    </PayPalScriptProvider>
  );
};

export default Paypal;
