import React, { useState, useEffect, useRef, useContext } from "react";
import ProductTab from "./product-tab";
import { useQuery } from "@apollo/client";
import { gql } from "@apollo/client";
import DetailsWithPrice from "./detail-price";
import { Container, Row, Col, Media, Button } from "reactstrap";
import jwtAxios from "../utils/Apis";
import { useRouter } from "next/router";
import WhyChoose from "./WhyChoose";
import FilterContext from "../helpers/filter/FilterContext";
import { Modal, Spin } from "antd";
import Mainbannerleft from "./selectVehicleModal";
import Link from "next/link";
import ProductImage from "./ProductImage";

const GET_SINGLE_PRODUCTS = gql`
  query product($id: Int!) {
    product(id: $id) {
      id
      title
      description
      type
      brand
      category
      price
      new
      sale
      discount
      stock
      variants {
        id
        sku
        size
        color
        image_id
      }
      images {
        alt
        src
      }
    }
  }
`;

const ProductSidebarPage = ({ pathId }) => {
  var { loading, data } = useQuery(GET_SINGLE_PRODUCTS, {
    variables: {
      id: parseInt(pathId),
    },
  });

  const [nav1, setNav1] = useState(null);
  const [nav2, setNav2] = useState(null);
  const [slider1, setSlider1] = useState(null);
  const [slider2, setSlider2] = useState(null);

  useEffect(() => {
    setNav1(slider1);
    setNav2(slider2);
  }, [slider1, slider2]);

  const filterClick = () => {
    document.getElementById("filter").style.left = "-15px";
  };

  const changeColorVar = (img_id) => {
    slider2.current?.slickGoTo(img_id);
  };
  const { selectedVehicle, vehicles } = useContext(FilterContext);
  const router = useRouter();
  const id = router.query.id;

  const [product, setProduct] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  const [isFit, setIsFit] = useState(false);

  useEffect(() => {
    // console.log(data, "data");
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(`product/find/${id}`);
        setProduct(response.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };

    if (id) {
      fetchData();
    }
  }, [id]);
  useEffect(() => {
    // console.log(data, "data");
    const checkFitment = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(
          `product/getProductsBySubCategoryId/${product?.sub_category_id}/${selectedVehicle}`
        );
        const fitmentproduct = response?.data?.products?.find(
          (p) => p.id == id
        );
        setIsFit(fitmentproduct ? true : false);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };

    if (product && selectedVehicle) {
      checkFitment();
    }
  }, [product, selectedVehicle]);

  const [open, setOpen] = useState(false);
  return (
    <div className="collection-wrapper">
      {!product || isLoading ? (
        <Container style={{ marginBottom: "100px" }}>
          <Row style={{ justifyContent: "center" }}>
            <Spin size="large" />
          </Row>
        </Container>
      ) : (
        <Container style={{ marginBottom: "100px" }}>
          <Row style={{ justifyContent: "center", display: "flex" }}>
            {!selectedVehicle ? (
              <Col sm="11" className="productcaution">
                <div>
                  <Media src="/assets/images/caution.png" width="60px" />
                </div>
                <div>Make sure this part fits your vehicle</div>
                <div>
                  <Button className="cautionbtn" onClick={() => setOpen(true)}>
                    {"Check Fit >"}
                  </Button>
                </div>
              </Col>
            ) : isFit ? (
              <Col sm="11" className="productcaution-fit">
                <div style={{ display: "flex", alignItems: "center" }}>
                  <Media
                    src="/assets/images/hashdecodes/check.png"
                    width="60px"
                  />
                  <div style={{ color: "#008006", marginLeft: "10px" }}>
                    <b>This part fits the vehicle you selected:</b>

                    <div style={{ display: "flex" }}>
                      <p>My Vehicle:</p>
                      <p
                        style={{
                          color: "black",
                          fontWeight: 600,
                          textTransform: "capitalize",
                        }}
                      >
                        {
                          vehicles?.find(
                            (sVehicle) => sVehicle.id == selectedVehicle
                          )?.company
                        }
                        {","}{" "}
                        {
                          vehicles?.find(
                            (sVehicle) => sVehicle.id == selectedVehicle
                          )?.model
                        }
                        {","}{" "}
                        {
                          vehicles?.find(
                            (sVehicle) => sVehicle.id == selectedVehicle
                          )?.year
                        }
                      </p>
                    </div>
                  </div>
                </div>

                <div>
                  <div
                    style={{
                      border: "0.8px solid #000",
                      padding: "10px",
                      backgroundColor: "white",
                    }}
                  >
                    <ul style={{ display: "flex", flexDirection: "column" }}>
                      <li>
                        <b>The vehicle options this part fits:</b>
                      </li>
                      <li className="fa fa-circle fitdot">
                        {" "}
                        <span className="fititem">
                          Production Date: 08/2013-08/2019 Fitting
                        </span>
                      </li>
                      <li className="fa fa-circle fitdot">
                        {" "}
                        <span className="fititem">
                          Vehicle Options: 1GRFE.. GRN28#
                        </span>
                      </li>
                    </ul>
                  </div>
                </div>
              </Col>
            ) : (
              <Col sm="11" className="productcaution">
                <div>
                  <Media
                    src="/assets/images/hashdecodes/danger.png"
                    width="60px"
                  />
                </div>
                <div style={{ display: "block" }}>
                  <div>
                    <b>This part does not fit the vehicle you selected:</b>
                  </div>
                  <div>
                    <h5
                      style={{
                        // color: "grey",
                        fontWeight: 700,
                        textTransform: "capitalize",
                      }}
                    >
                      My Vehicle:
                      {
                        vehicles?.find(
                          (sVehicle) => sVehicle.id == selectedVehicle
                        )?.company
                      }
                      {","}{" "}
                      {
                        vehicles?.find(
                          (sVehicle) => sVehicle.id == selectedVehicle
                        )?.model
                      }
                      {","}{" "}
                      {
                        vehicles?.find(
                          (sVehicle) => sVehicle.id == selectedVehicle
                        )?.year
                      }
                    </h5>
                  </div>
                  <div>
                    <Button
                      onClick={() =>
                        router.push(`/shop/parts-by-selected-vehicle`)
                      }
                      className="cautionbtn"
                    >
                      View Similar Parts That Fit
                    </Button>
                  </div>
                </div>
              </Col>
            )}
            {open && (
              <Modal
                open={open}
                onCancel={() => setOpen(false)}
                width={800}
                footer={null}
                onOk={() => setOpen(false)}
                title={null}
              >
                <Mainbannerleft setOpen={setOpen} />
              </Modal>
            )}
          </Row>

          <Row
            style={{
              justifyContent: "center",
              marginTop: "40px",
              marginBottom: "40px",
            }}
          >
            <Col sm="12" xl="12">
              {!product || isLoading ? (
                <Row>
                  <Col lg="4"></Col>
                  <Col lg="4">
                    <Spin size="large" />
                  </Col>
                  <Col lg="4"></Col>
                </Row>
              ) : (
                <Row>
                  <Col
                    lg="4"
                    // sm="2"
                    className="product-thumbnail"
                    style={{
                      justifyContent: "center",
                      display: "flex",
                      alignItems: "center",
                    }}
                  >
                    <Link href={"/product-details/" + product.id}>
                      <ProductImage product={product} />
                    </Link>
                  </Col>
                  <Col lg="8" className="rtl-text product-ps">
                    <DetailsWithPrice
                      item={product}
                      changeColorVar={changeColorVar}
                    />
                  </Col>
                </Row>
              )}
            </Col>
          </Row>

          <Row style={{ justifyContent: "center" }}>
            <Col
              lg="12"
              style={{ display: "flex", justifyContent: "space-between" }}
              className="producttabs"
            >
              <Col lg="9" className="rtl-text product-ps">
                <ProductTab product={product} />
              </Col>
              <Col
                lg="3"
                className="rtl-text product-ps"
                style={{
                  paddingTop: "40px",
                  paddingLeft: "30px",
                  paddingRight: "0px",
                }}
              >
                <WhyChoose />
              </Col>
            </Col>
          </Row>
        </Container>
      )}
    </div>
    // </section>
  );
};

export default ProductSidebarPage;
