import React, { useEffect, useState } from "react";
import jwtAxios from "../utils/Apis";
import errorHandler from "../utils/errorHandler";
import { Table } from "antd";
import Link from "next/link";

const RelatedProductTable = ({ id }) => {
  const [products, setProducts] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  useEffect(() => {
    // console.log(data, "data");
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(`/related-products/${id}`);
        setProducts(response.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };

    if (id) {
      fetchData();
    }
  }, [id]);
  const columnsRelated = [
    {
      title: "Manufacturer",
      dataIndex: "manufacturer",
      key: "manufacturer",
    },
    {
      title: "Part No.",
      dataIndex: "part_number",
      key: "part_number",
    },
    {
      title: "Desc.",
      dataIndex: "description",
      key: "description",
    },
    {
      title: "Condition",
      dataIndex: "condition",
      key: "condition",
    },
    {
      title: "Availability",
      dataIndex: "available_stock",
      key: "available_stock",
    },
    {
      title: "Price",
      dataIndex: "wholesale_price",
      key: "wholesale_price",
      render: (p) => <>${p?.toFixed(2)}</>,
    },
    {
      title: "View",
      key: "view",
      render: (p) => (
        <Link href={`/product-details/${p.id}`} style={{ color: "#2e5ba5" }}>
          More
        </Link>
      ), // Replace '#' with your actual link
    },
  ];

  return (
    <>
      <Table
        // showHeader={false}
        size="small"
        dataSource={products}
        columns={columnsRelated}
        pagination={false}
        scroll={{ x: 100 }}
      />
    </>
  );
};

export default RelatedProductTable;
