import React, { useState, useEffect, useContext } from "react";
import { Select, Spin, Empty } from "antd";
import { Router, useRouter } from "next/router";
import jwtAxios from "../../utils/Apis";

const { Option } = Select;

const SelectSearch = ({ route, fields, city, className }) => {
  const [data, setData] = useState([]);
  const [search, setSearch] = useState("");
  const [value, setValue] = useState();
  const [loading, setLoading] = useState(false);
  const fetchAPI = async (query) => {
    const response = await jwtAxios.get(`product/search/${query}`);
    return response.data;
  };

  useEffect(() => {
    if (search.length >= 2) {
      setLoading(true);
      fetchAPI(search)
        .then((newData) => {
          setData(newData);
        })
        .catch((error) => console.log(error))
        .finally(() => setLoading(false));
    } else {
      setData([]);
    }
  }, [search]);

  const options = data?.map((d) => (
    <Option key={d.id} value={d.id}>
      {d.name}
    </Option>
  ));

  const noDataMessage =
    search.length >= 2 ? (
      loading ? (
        <Spin size="small" />
      ) : (
        <Empty description="No result available" />
      )
    ) : (
      "Start typing to find parts"
    );
  const router = useRouter();
  const handleSelect = (value) => {
    router.push(`/product-details/${value}`);
  };
  return (
    <Select
      className={className}
      showSearch
      removeIcon
      allowClear
      suffixIcon={null}
      value={value}
      onClear={() => setSearch("")}
      // size="large"
      style={{
        border: "none",
        background: "#f1f1f1",
        width: "425px",
        height: "auto",
        color: "#000",
      }}
      placeholder="Search by Part Number, Part Name, Description"
      onSelect={handleSelect}
      onSearch={setSearch}
      loading={loading}
      filterOption={(input, option) =>
        option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
      }
      notFoundContent={noDataMessage}
    >
      {options}
    </Select>
  );
};

export default SelectSearch;
