import React, { useState, useContext, useEffect } from "react";
import { Col, Row, Media, Button, Spinner } from "reactstrap";

const PolicyList = ({ colClass, layoutList, openSidebar, noSidebar }) => {
  return (
    <Col className="collection-content">
      <div className="page-main-content">
        <p> </p>
        <Row style={{ border: "1px solid #000" }}>
          <Col sm="12">
            <div className="top-banner-wrapper">
              <div className="top-banner-content small-section">
                <h4>Sales Policy</h4>
                <h5>Terms and Conditions</h5>
                <p>
                  The use of this site is governed by the policies, terms and
                  conditions set forth below. Please read them carefully. The
                  usage of this site and your placement of an order indicate an
                  acceptance of these terms and conditions.
                </p>
                <h5>Shipping Information</h5>
                <p>
                  We ship worldwide. Available shipping methods vary depending
                  on products and shipping destinations.
                </p>
                <p>
                  Shipments can also be sent to both PO Boxes and Military
                  APO/FPO addresses. Please allow additional time for orders
                  shipped to APO/FPO addresses. Expedited shipping or large item
                  shipment is not available to these address types.
                </p>
                <p>
                  If you are shipping to a U.S. Territory (Puerto Rico, Guam,
                  U.S. Virgin Islands, American Samoa, Northern Mariana Islands,
                  and Micronesia) the shipment will be serviced by USPS.
                </p>
                <p>
                  For international orders, duties and fees are not included in
                  the purchase price. Buyers are responsible for any customs
                  fees that may incur, including duties, taxes, brokerage fees,
                  and any other fees. We have no control over these fees.
                </p>
                <p>
                  If you are placing an order with a high amount, please contact
                  us for assistance on possible alternative payment methods.
                </p>
                <p>
                  Most of the orders are processed and shipped out within 1-3
                  business days. However due to item availability and warehouse
                  locations, your items may be split shipped when you place an
                  order for multiple items. If a part is not in-stock, it will
                  be ordered directly from the main OEM distribution centers.
                  This will take additional time for the items to arrive to our
                  warehouse before it is shipped to you. Thus, when you choose
                  Overnight delivery, it does not mean that you will receive
                  your order tomorrow. All orders must be shipped; there is no
                  pick-up service offered.
                </p>
                <p>
                  Once an order has been shipped, an invoice will be emailed to
                  you. The tracking number can be found on the sales invoice. To
                  view more tracking information, you can use the tracking
                  number link provided on the sales invoice. You can also use
                  the provided tracking number on USPS.com, UPS.com, or
                  FedEx.com. It is ourresponsibility to ensure packages are
                  shipped out and it is the customer's responsibility to ensure
                  successful delivery once the tracking number has been
                  provided. If there is an issue with the delivery of your
                  package you can contact us for assistance.
                </p>
                <p>
                  Once an order status shows as "Packaging," "Packaging with
                  Parts On Order," or"Shipped," it cannot be modified or
                  cancelled.
                </p>
                <h5>
                  Customers will be responsible and charged for any additional
                  shipping fee if any of the following situations occur:
                </h5>
                <h5>Inaccurate / Undeliverable Shipping Address</h5>
                <p>
                  Please make sure that your shipping address is deliverable and
                  complete. Toyotapartsdeal.com is not liable for any inaccurate
                  / undeliverable shipping address. It is the customer's
                  responsibility to provide the correct and deliverable shipping
                  address for USPS/UPS/FedEx delivery upon submitting the order.
                  Any charges incurred by us while rerouting or making an
                  address correct will be the responsibility of the customer.
                </p>
                <h5>Unsuccessful Delivery</h5>
                <p>
                  UPS and FedEx make up to three delivery attempts, excluding
                  weekends and holidays. Once the third and final delivery
                  attempt has been made and the driver was unable to leave the
                  package, UPS or FedEx will return the package to the sender.
                  Customer will be responsible and charged for the shipping fee
                  TWICE, for both the original delivery charges and the
                  undeliverable package.
                </p>
                <p>
                  USPS will leave a peach-colored slip when the carrier
                  attempted to deliver an item or items to you. A redelivery can
                  be scheduled to take place up to the day the item is scheduled
                  for return to the sender (the Final Notice date on the front
                  of the form).
                </p>
                <h5>Refused Shipments</h5>
                <p>
                  Freight charges incurred by us while attempting to deliver
                  merchandise which is refused, will be billed to the customer.
                  A 20% re-stocking fee will apply to any merchandise bounced
                  back to our warehouse.
                </p>
                <h5>Return to Shipper Orders</h5>
                <p>
                  All packages that return to our facility due to an incomplete
                  delivery will be subject to a 20% restocking fee,
                  undeliverable package return charge, and any additional
                  charges incurred due to the returned package. Credit will be
                  issued after the 20% restocking fee and undeliverable package
                  return charge (same cost as original shipping) has been
                  applied to the price of the part, where original shipping
                  costs cannot be refunded.
                </p>
                <h5>In Transit</h5>
                <p>
                  The tracking number is emailed once an order is shipped out.
                  Should the tracking number be invalid or show no tracking
                  updates, please allow 24 hours for the tracking number to
                  update on the USPS/UPS/FedEx website. If the tracking number
                  continues to appear invalid or shows no movement, please
                  contact us for assistance.
                </p>
                <p>
                  If the tracking information shows the wrong destination,
                  please contact us for immediate assistance. An additional fee
                  will apply to any qualified address corrections. Otherwise,
                  you may contact UPS and request for a Will Call, which will
                  allow you to pick up the package within 5 business days at a
                  local customer center. A valid government issued ID is
                  required for Will Calls.
                </p>
                <h5>Sales Tax</h5>
                <p>
                  Due to a recent Supreme Court ruling, states now have the
                  ability to mandate whether or not they charge sales tax for
                  online purchases. We collect and remit sales tax to remain
                  compliant with all applicable tax laws as mandated by the
                  state governments in which we conduct business.
                </p>
                <p>
                  If your order is shipped to one of the states which mandates
                  collection of online sales tax, it is subject to sales tax.
                  Please consult a tax professional for more information
                  regarding applicable sales taxes on your order.
                </p>
                <p>
                  For Tax Exempt Purchases, you must qualify for tax exempt
                  purchases by submitting your business account application.
                  Please be aware you will be asked to upload a copy of your
                  seller certification. If you have placed orders while your Tax
                  Exemption Certificate is being verified, all tax on orders may
                  be returned to the original payment method once the
                  verification process has been completed.
                </p>
                <h5>Pricing</h5>
                <p>
                  Although we try our best to maintain an error-free website, a
                  small number of the parts on our catalog may be mispriced. If
                  the correct price is lower than the listed price, we will
                  invoice you for the lower amount and ship out the order. If
                  the part's correct price is higher than our listed price, we
                  will inform you first to see whether the order should be
                  proceed or canceled.
                </p>
                <h5>Lowest Price Guarantee</h5>
                <p>
                  Prior to placing your order, contact us by Phone, Live Chat,
                  or Email and provide us a link to the online retailer we are
                  matching. We will verify the item eligibility by reviewing the
                  online retailer. Toyotapartsdeal.com will match the price from
                  an online retailer only and has the final decision for
                  matching an online price. If we match an online retailer’s
                  price, it must include shipping charges in the price of the
                  item. The item must be identical and must have the same
                  manufacturer part number. Price matching is not available on
                  previously placed orders and only applies to orders shipped in
                  the United States.
                </p>
                <p>Price Matching Excludes:</p>
                <p>Reconditioned/Refurbished Parts</p>
                <p>Prices from Marketplace and third-party sellers</p>
                <p>Prices from auctions or requiring memberships</p>
                <p>Inaccurate prices</p>
                <p>
                  Oversize items that must ship freight. This applies, but is
                  not limited to all bumpers, fenders, hoods, door panels, etc.
                </p>
                <p>Special order parts</p>
                <p>
                  Price match cannot be combined with other promotional offers
                </p>
                <p>
                  In the rare case of a website error in that a part is listed
                  for much less than the actual price, we will contact the
                  customer with the real price before processing the order.
                  Toyotapartsdeal.com reserves the right to cancel orders if the
                  customer does not agree to the actual price.
                </p>
                <p>
                  *Price matching is at the discretion of Toyotapartsdeal.com
                </p>
                <p>
                  *Toyotapartsdeal.com reserves the right to modify the terms of
                  this policy at any time without notice.
                </p>
                <h5>Shipping Cost</h5>
                <p>
                  Most of our shipments will be shipped via USPS. For Oversized
                  or Overweight shipments, there will be an additional shipping
                  charge required. This applies, but is not limited to all
                  bumpers, fenders, hoods, door panels, etc. Please email us for
                  freight charge information on these parts.
                </p>
                <p>
                  In rare occasions where the actual cost is higher than the
                  estimate, we will always inform you first for further
                  instructions before proceeding with the order. All shipping
                  cost calculations are estimates from USPS/UPS/FedEx. Some
                  orders may require a signature to receive the delivery.
                </p>
                <h5>Order Processing</h5>
                <p>
                  Customers are not charged until their order is ready to ship.
                  Most orders will be verified by our customer service
                  representatives within 24 business hours before it is
                  forwarded to our parts department for processing.
                </p>
                <h5>Credit Card/Fraud Prevention</h5>
                <p>
                  To prevent fraudulent activities, we will conduct address
                  verification through the customer's credit/debit card issuer
                  to confirm customer's identity and verify the validity of your
                  purchase, ultimately protecting the customer's privacy.
                </p>

                <p>
                  If you wish to ship to an address other than your billing
                  address, please contact the card issuer and have your shipping
                  destination added as an authorized alternate ship-to address
                  in the record/memo field. We will contact your credit card
                  issuer to verify this information after you've placed an
                  order.
                </p>

                <p>
                  Both your billing and shipping addresses must be verified
                  before an order will ship. If you encounter any trouble while
                  attempting to add an alternate shipping address, let the card
                  issuer know that you are placing an online order and that the
                  retailer must verify your personal information before shipment
                  to eliminate the possibility of fraud. Then, inform us when
                  the information has been updated and we will re-attempt the
                  address verification to complete the processing of your order.
                </p>

                <p>
                  Orders with the same verified billing and shipping address
                  will be processed much faster.
                </p>
                <h5>Packaging</h5>
                <p>
                  Most of the parts will be shipped in their original genuine
                  factory boxes or packaging. On rare occasions, we might have
                  to repackage the parts before shipping due to the shape, size,
                  or possibility of damage. Therefore, they may arrive in
                  different boxes with the original packaging inside. All of our
                  parts are genuine OEM and are covered by the standard
                  manufacturer warranty.
                </p>
                <h5>Backorders</h5>
                <p>
                  In the event of a backorder part (less {"<"} 1% ), we will
                  inform the customer and provide him/her with the option to
                  cancel the part or the entire order. If customer is willing to
                  wait, the customer's credit card will not be charged and
                  invoiced until the parts arrive at our warehouse and the order
                  is ready for shipment.
                </p>

                <h5>Disclaimer</h5>

                <p>
                  Some parts on your order may have updated replacement
                  information. Our parts specialists will verify and ship out
                  the updated replacement at our discretion. In the meantime,
                  the updated replacement part number will be provided on the
                  packing list and invoice.
                </p>

                <p>
                  Vehicle diagrams displayed on this website are for general
                  illustration purposes only. Vehicles depicted are shown as a
                  sample vehicle of the same model only. Details of a selected
                  vehicle may vary from the vehicle shown, depending on the
                  selected features. The diagrams are used as a point of
                  reference and should not be used as the primary resource when
                  ordering a part.
                </p>

                <p>
                  The catalog is provided as a convenience to our customers. We
                  do not guarantee the accuracy of the information provided
                  within this catalog. While we try to maintain a near-perfect
                  catalog, a small number of parts may be listed incorrectly.
                  Our website is a general catalog and does not reflect our
                  actual inventory, please contact us for inventory information.
                </p>

                <p>
                  We reserve the right to refuse to process an order for any
                  reason. Your order confirmation is an offer to buy, not a
                  completed sales contract. Order acceptance and the completion
                  of the contract between both the purchasing and seller party
                  will take place on the shipment of the products ordered. Your
                  receipt of an electronic or other form of order confirmation
                  does not mean our acceptance of your order, nor does it
                  constitute a confirmation of our offer to sell.
                </p>

                <p>
                  We reserve the right at any time after the receipt of your
                  order to cancel your order for any reason. If the order is
                  cancelled, the authorization on your card will be voided and
                  no money will be charged. If your card has been charged, a
                  refund will be issued to your credit card.
                </p>

                <h5>Limitation of liability</h5>
                <p>
                  Toyotapartsdeal.com and its affiliates will not be liable for
                  any direct, indirect, incidental, punitive, consequential, or
                  any other damages whatsoever that result from the use or
                  performance of, or the inability to use, the site, the
                  products, or information, or functions on such site, even if
                  Toyotapartsdeal.com has been advised of the possibility of
                  such damages. In no event will Toyotapartsdeal.com and its
                  affiliates' total liability to you for all damages, losses,
                  and causes of action, whether arising out of contract, tort,
                  or otherwise, exceed the amount paid by you, if any, for
                  accessing the site or purchasing the products.
                </p>
              </div>
            </div>
          </Col>
        </Row>
      </div>
    </Col>
  );
};

export default PolicyList;
