import React, { useState, useContext, useEffect } from "react";
import { Col, Row, Media, Button, Spinner } from "reactstrap";

import { gql } from "@apollo/client";
import FilterContext from "../helpers/filter/FilterContext";
import ProductItem from "./common/product-box/ProductBox1";
import { CurrencyContext } from "../helpers/Currency/CurrencyContext";
import { useRouter } from "next/router";
import PostLoader from "./common/PostLoader";
import CartContext from "../helpers/cart";
import { WishlistContext } from "../helpers/wishlist/WishlistContext";
import { CompareContext } from "../helpers/Compare/CompareContext";
import { List, Popover } from "antd";
import SubProducts from "./SubProducts";
import Link from "next/link";

const GET_PRODUCTS = gql`
  query products(
    $type: _CategoryType!
    $indexFrom: Int!
    $limit: Int!
    $color: String!
    $brand: [String!]!
    $sortBy: _SortBy!
    $priceMax: Int!
    $priceMin: Int!
  ) {
    products(
      type: $type
      indexFrom: $indexFrom
      limit: $limit
      color: $color
      brand: $brand
      sortBy: $sortBy
      priceMax: $priceMax
      priceMin: $priceMin
    ) {
      total
      hasMore
      items {
        id
        title
        description
        type
        brand
        category
        price
        new
        sale
        stock
        discount
        variants {
          id
          sku
          size
          color
          image_id
        }
        images {
          image_id
          id
          alt
          src
        }
      }
    }
  }
`;

const PolicyList = ({ data }) => {
  const filterContext = useContext(FilterContext);
  const selectedBrands = filterContext.selectedBrands;
  const selectedColor = filterContext.selectedColor;
  const selectedPrice = filterContext.selectedPrice;
  const selectedSize = filterContext.selectedSize;
  const selectedVehicle = filterContext.selectedVehicle;
  const [url, setUrl] = useState();

  useEffect(() => {
    const pathname = window.location.pathname;
    setUrl(pathname);
  }, [selectedBrands, selectedColor, selectedSize, selectedPrice]);

  return (
    <Col className="collection-content">
      <div className="page-main-content" style={{ padding: "0px" }}>
        {/* <p>
          Home {">"} <b>Parts and Categories</b>
        </p> */}

        <Row style={{}}>
          <h4 className="category-list-top">Parts and Accessories</h4>

          <Col
            sm="12"
            style={{
              padding: "0px",
              border: "1px solid #BC0200",
              padding: "20px",
            }}
          >
            <div className="top-banner-wrapper">
              <div
                className="top-banner-content small-section"
                style={{ marginTop: "0px" }}
              >
                {data?.map((category, i) => (
                  <List
                    size="large"
                    header={<h3 className="titlevehicle">{category?.name}</h3>}
                    // footer={<div>Footer</div>}
                    // bordered
                    dataSource={
                      category?.sub_categories ? category?.sub_categories : []
                    }
                    renderItem={(item) => (
                      <List.Item
                        // onClick={clickSubCat(item.id)}
                        className="listitems"
                      >
                        <Popover
                          placement="bottomRight"
                          className="listitems-content"
                          title={`Parts in ${item.name}`}
                          content={
                            <SubProducts
                              subCategoryId={item.id}
                              vehicleId={selectedVehicle}
                            />
                          }
                        >
                          <Link
                            href={{
                              pathname: `/sub-categories/${item.id}`,
                              query: { param1: item.name },
                            }}
                          >
                            <b style={{ color: "#2E5BA5 !importatnt" }}>
                              {item.name}
                            </b>
                            <li
                              style={{ color: "#2E5BA5 !importatnt" }}
                              className="fa fa-wpexplorer"
                            ></li>
                          </Link>
                        </Popover>
                      </List.Item>
                    )}
                  />
                ))}
              </div>
            </div>
          </Col>
        </Row>
      </div>
    </Col>
  );
};

export default PolicyList;
