import React, { useContext, useEffect, useState } from "react";
import jwtAxios from "../utils/Apis";
import errorHandler from "../utils/errorHandler";
import { List } from "antd";
import { useRouter } from "next/router";
import FilterContext from "../helpers/filter/FilterContext";

const SubProducts = ({ subCategoryId, vehicleId }) => {
  const router = useRouter();
  const [data, setData] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  const { selectedVehicle } = useContext(FilterContext);
  useEffect(() => {
    // console.log(data, "data");
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(
          `product/getProductsBySubCategoryId/${subCategoryId}/${vehicleId}`
        );
        setData(response.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };
    fetchData();
  }, [subCategoryId, vehicleId, selectedVehicle]);
  return (
    <>
      <List
        dataSource={data ? data.products : []}
        renderItem={(item) => (
          <List.Item onClick={() => router.push(`/product-details/${item.id}`)}>
            {item.name}
          </List.Item>
        )}
      />
    </>
  );
};

export default SubProducts;
