import React, { useContext, useEffect, useState } from "react";
import jwtAxios from "../utils/Apis";
import errorHandler from "../utils/errorHandler";
import { Table, notification } from "antd";
import Link from "next/link";
import { isBusiness } from "./constant/menu";
import { UserContext } from "../helpers/loginContext/loginContext";
import { useRouter } from "next/router";

const WholsaleProducts = ({ id }) => {
  const { user } = useContext(UserContext);
  const router = useRouter();
  const [products, setProducts] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  useEffect(() => {
    if (!isBusiness(user)) {
      notification.info({
        message: `Need Business Account`,
        description:
          "To view wholesale segment you must have a business account!",
        placement: "bottomRight",
      });
      router.push("/");
    }
  }, []);
  useEffect(() => {
    // console.log(data, "data");
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(`getWholesale`);
        setProducts(response.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };

    if (id) {
      fetchData();
    }
  }, [id]);
  const columnsRelated = [
    {
      title: "Part No.",
      dataIndex: "part_number",
      key: "part_number",
    },
    {
      title: "Desc.",
      dataIndex: "description",
      key: "description",
    },
    {
      title: "Availability",
      dataIndex: "available_stock",
      key: "available_stock",
    },
    {
      title: "Price",
      dataIndex: "wholesale_price",
      key: "wholesale_price",
      render: (p) => <>${p?.toFixed(2)}</>,
    },
    {
      title: "View",
      key: "view",
      render: (p) => (
        <Link href={`/product-details/${p.id}`} style={{ color: "#2e5ba5" }}>
          More Details
        </Link>
      ), // Replace '#' with your actual link
    },
  ];

  return (
    <>
      <Table
        // showHeader={false}
        size="small"
        dataSource={products}
        columns={columnsRelated}
        pagination={false}
        scroll={{ x: 100 }}
      />
    </>
  );
};

export default WholsaleProducts;
