import React, { useState, useContext } from "react";
import Link from "next/link";
import CartContext from "../helpers/cart";
import { Container, Row, Col, Media, Table } from "reactstrap";
import { CurrencyContext } from "../helpers/Currency/CurrencyContext";
import cart from "../public/assets/images/icon-empty-cart.png";
import { isBusiness } from "./constant/menu";
import { UserContext } from "../helpers/loginContext/loginContext";
import ProductImage from "./ProductImage";
import { notification } from "antd";

const CartPage = () => {
  const { user } = useContext(UserContext);
  const context = useContext(CartContext);
  const cartItems = context.state;
  const curContext = useContext(CurrencyContext);
  const symbol = curContext.state.symbol;
  const total = context.cartTotal;
  const removeFromCart = context.removeFromCart;

  const [quantityError, setQuantityError] = useState(false);
  const updateQty = context.updateQty;

  const handleQtyUpdate = (item, quantity) => {
    const minimumQuantity = isBusiness(user) ? item.minimum_quantity : 1;

    if (quantity < minimumQuantity) {
      notification.info({
        message: "Minimum Allowed",
        description: "This quantity is the minimum allowed quantity!",
        placement: "bottomRight",
      });
      updateQty(item, minimumQuantity);
    } else if (quantity > item.available_stock) {
      notification.info({
        message: "Maximum Stock",
        description: "This quantity is the maximum available stock!",
        placement: "bottomRight",
      });
      updateQty(item, item.available_stock);
    } else {
      updateQty(item, quantity);
    }
  };

  return (
    <div>
      {cartItems && cartItems.length > 0 ? (
        <section className="cart-section section-b-space">
          <Container>
            <Row>
              <Col sm="12">
                <Table className="table cart-table table-responsive-xs">
                  <thead>
                    <tr className="table-head">
                      <th scope="col">image</th>
                      <th scope="col">product name</th>
                      <th scope="col">price</th>
                      <th scope="col">quantity</th>
                      <th scope="col">action</th>
                      <th scope="col">total</th>
                    </tr>
                  </thead>
                  {cartItems.map((item, index) => {
                    return (
                      <tbody key={index}>
                        <tr>
                          <td>
                            <Link href={`/product-details/` + item.id}>
                              {/* <Media
                                src={
                                  item?.images
                                    ? JSON.parse(item?.images)[0]?.image1
                                    : "/assets/images/no-image.png"
                                }
                                alt=""
                              /> */}
                              <ProductImage product={item} />
                            </Link>
                          </td>
                          <td>
                            <Link href={`/product-details/` + item.id}>
                              {item.name}
                            </Link>
                            <div className="mobile-cart-content row">
                              <div className="col-xs-3 mobcart">
                                <div className="qty-box">
                                  <div className="input-group">
                                    <input
                                      type="number"
                                      name="quantity"
                                      // max={item.available_stock}
                                      onChange={(e) =>
                                        handleQtyUpdate(item, e.target.value)
                                      }
                                      className="form-control input-number"
                                      value={item.qty}
                                      style={{
                                        borderColor: quantityError && "red",
                                      }}
                                    />
                                  </div>
                                </div>
                              </div>
                              <div className="col-xs-3 mobcart">
                                <h2
                                  className="td-color"
                                  style={{ color: "#2E5BA5" }}
                                >
                                  ${item.price?.toFixed(2)}
                                </h2>
                              </div>
                              <div className="col-xs-3 mobcart">
                                <h2 className="td-color">
                                  <a href="#" className="icon">
                                    <i
                                      // className="fa fa-times"
                                      onClick={() => removeFromCart(item)}
                                      style={{ color: "#E52222" }}
                                    >
                                      <li className="fa fa-trash"></li>
                                    </i>
                                  </a>
                                </h2>
                              </div>
                            </div>
                          </td>
                          <td>
                            <h2>${item.price?.toFixed(2)}</h2>
                          </td>
                          <td>
                            <div className="qty-box">
                              <div className="input-group">
                                <input
                                  type="number"
                                  name="quantity"
                                  onChange={(e) =>
                                    handleQtyUpdate(item, e.target.value)
                                  }
                                  className="form-control input-number"
                                  value={item.qty}
                                  style={{
                                    borderColor: quantityError && "red",
                                  }}
                                />
                              </div>
                            </div>
                          </td>
                          <td>
                            <i
                              className="fa fa-times"
                              onClick={() => removeFromCart(item)}
                            ></i>
                          </td>
                          <td>
                            <h2 className="td-color">
                              {`$${item?.total?.toFixed(2)}`}
                            </h2>
                          </td>
                        </tr>
                      </tbody>
                    );
                  })}
                </Table>
                <table className="table cart-table table-responsive-md responsive-table-responsive-md">
                  <tfoot>
                    <tr>
                      <td>total price :</td>
                      <td>
                        <h2 className="carttotal">{`$${total?.toFixed(2)}`}</h2>
                      </td>
                    </tr>
                  </tfoot>
                </table>
              </Col>
            </Row>
            <Row className="cart-buttons responsive-cart-bton">
              <Col xs="8">
                <Link href={`/page/parts`} className="btn btn-solid catbtn">
                  continue shopping
                </Link>
              </Col>
              <Col xs="4">
                <Link
                  href={`/page/account/checkout`}
                  className="btn btn-solid catbtn"
                >
                  check out
                </Link>
              </Col>
            </Row>
          </Container>
        </section>
      ) : (
        <section className="cart-section section-b-space">
          <Container>
            <Row>
              <Col sm="12">
                <div>
                  <div className="col-sm-12 empty-cart-cls text-center">
                    <Media
                      src={cart}
                      className="img-fluid mb-4 mx-auto"
                      alt=""
                    />
                    <h3>
                      <strong>Your Cart is Empty</strong>
                    </h3>
                    <h4>Explore more shortlist some items.</h4>
                  </div>
                </div>
              </Col>
            </Row>
          </Container>
        </section>
      )}
    </div>
  );
};

export default CartPage;
