import React, { useContext, useEffect, useState } from "react";
import { Media, Container, Row, Col } from "reactstrap";
import CartContext from "../helpers/cart";
import { CurrencyContext } from "../helpers/Currency/CurrencyContext";

import paypal from "../public/assets/images/pay-paypal.png";
import creditCardLogo from "../public/assets/images/pay-credit-cards.png";
// import { PayPalButton } from "react-paypal-button-v2";

import { Checkbox, Form, Input, Select, Button, Spin } from "antd";
import PhoneCodes from "./constant/Codes";
import AddressForm from "./AddressForm";
import { useRouter } from "next/router";

import { loadStripe } from "@stripe/stripe-js";
import jwtAxios, { API_BASE_URL } from "../utils/Apis";
import Paypal from "./Paypal";
import Link from "next/link";
// Assuming this function is in a separate module or file
export function getTotalCost(cartItems, isStandardShip, shippingData) {
  // Check if cartItems is not an array or shippingData is null or undefined
  if (!Array.isArray(cartItems) || !shippingData) {
    return 0;
  }

  let totalWeight = 0;

  // Loop through each item in cartItems
  cartItems.forEach((item) => {
    let productWeight = 0;
    let dimensionWeight = 0;

    // Check if item has valid numeric values for "item-weight" and qty
    if (item && typeof item["item-weight"] === "number") {
      productWeight = parseFloat(item["item-weight"]);
    }

    // Check if item has valid numeric values for dimensions and cubicSize
    if (
      item &&
      typeof item.item_width === "number" &&
      typeof item.item_length === "number" &&
      typeof item.item_height === "number" &&
      typeof item.cubicSize === "number"
    ) {
      dimensionWeight =
        (item.item_width * item.item_length * item.item_height) /
          item.cubicSize || 0;
    }

    totalWeight += Math.max(productWeight, dimensionWeight) * item.qty || 0;
  });

  // Choose the appropriate shipping cost based on isStandardShip
  const selectedShippingCost = isStandardShip
    ? parseFloat(shippingData?.domestic_standard_shipping) || 0
    : parseFloat(shippingData?.domestic_expedited_shipping) || 0;

  const selectedWeightCost = isStandardShip ? 0.5 : 0.99;

  const totalCost = selectedShippingCost + totalWeight * selectedWeightCost;

  return totalCost;
}

const CheckoutPage = ({ user, address }) => {
  const cartContext = useContext(CartContext);
  const cartItems = cartContext.state;
  const cartTotal = cartContext.cartTotal;
  const curContext = useContext(CurrencyContext);
  const symbol = curContext.state.symbol;
  const [payment, setPayment] = useState("stripe");
  const [isStandardShip, setisStandardShip] = useState(true);

  const [values, setValues] = useState(null);
  const [shipCost, setShipCost] = useState(0);
  const [data, setData] = useState(null);
  const [loading, setLoading] = useState(false);
  const [editAddress, setEditAddress] = useState(false);
  const router = useRouter();

  const clickDetail = () => {
    router.push(`/`);
  };

  const checkhandle = (value) => {
    setPayment(value);
  };
  ///

  const fetchData = async () => {
    try {
      const response = await jwtAxios.get(`shipment-cost`);
      console.log(response, "response");
      setData(response.data.value);
    } catch (error) {
      errorHandler(error);
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchData();
  }, []);
  useEffect(() => {}, [shipCost]);
  useEffect(() => {
    data &&
      setShipCost(getTotalCost(cartItems, isStandardShip, JSON.parse(data)));
  }, [isStandardShip, data, cartItems]);
  const [form] = Form.useForm();
  useEffect(() => {
    console.log(address);
    // Auto-fill form when user logs in
    if (address?.length > 0) {
      form.setFieldsValue({
        first_name: address[0].first_name,
        last_name: address[0].last_name,
        zip_code: address[0].zip_code,
        company: address[0].company,
        country: address[0].country,
        phone: address[0].phone,
        address_1: address[0].address_1,
        address_2: address[0].address_2,
        city: address[0].city,
        state: address[0].state,
      });
    }
  }, [address, user]);
  const makePayment = async () => {
    setLoading(true);
    const stripe = await loadStripe(
      "pk_test_51OXKUFF3x6ykuwLIwtzD5xl5HFcIY84MG26asVFK8DGT8HHG375uGNLbdx7eIBT4XH4EQe2fqawHO4cdKg8x1TbG00L1JazbjC"
    );

    const session = await jwtAxios.post("create-checkout-session", {
      products: [
        ...cartItems,
        { name: "Shipping Fee", price: shipCost, qty: 1, ship_cost: 0 },
      ],
      // ship_cost: 0,
    });

    // const session = await response.json();
    console.log(session);
    const result = stripe.redirectToCheckout({
      sessionId: session.data.id,
    });

    if (result.error) {
      setLoading(false);
      console.log(result.error);
    }
  };

  const handleFormSubmission = () => {
    form
      .validateFields()
      .then((values) => {
        values.ship_cost = shipCost;
        setValues(values);

        localStorage.setItem("orderData", JSON.stringify(values));
        // makePayment();
        router.push({
          pathname: router.pathname,
          query: { param1: "stripe" },
        });
        setEditAddress(true);
      })
      .catch((errorInfo) => {
        // Handle validation errors if needed
        console.error("Validation failed:", errorInfo);
      });
  };
  return (
    <section className="section-b-space">
      <Container>
        <div className="checkout-page">
          {user?.id ? (
            " "
          ) : (
            <>
              <h6 className="title-font">
                <Link
                  href={`/page/account/login`}
                  style={{ fontSize: "14px", color: "#2E5BA5" }}
                >
                  <b> Login </b>
                </Link>
                or continue as Guest?{" "}
              </h6>
            </>
          )}
          <div className="checkout-form">
            <Form
              form={form}
              layout="vertical"
              initialValues={{ useSameAsShipping: true }}
            >
              <Row>
                <Col lg={"6"} sm="12" xs="12">
                  {router.query.param1 ? (
                    <>
                      <Row>
                        <Col sm="6">
                          <div className="box">
                            <div className="box-title dashboard">
                              <h3>Shipping Address</h3>
                            </div>
                            <Row>
                              <Col sm="12">
                                <address>
                                  <strong>Company:</strong>{" "}
                                  {values?.company || " "}
                                  <br />
                                  <strong>Address line 1:</strong>{" "}
                                  {values?.address_1 || " "}
                                  <br />
                                  <strong>Address line 2:</strong>{" "}
                                  {values?.address_2 || " "}
                                  <br />
                                  <strong>Country:</strong>{" "}
                                  {values?.country || " "}
                                  <br />
                                  <strong>Zip code:</strong>{" "}
                                  {values?.zip_code || " "}
                                  <br />
                                  <strong>Phone:</strong> {values?.phone || " "}
                                  <br />
                                  <strong>City:</strong> {values?.city || " "}
                                  <br />
                                  <strong>State:</strong> {values?.state || " "}
                                </address>
                              </Col>
                            </Row>
                          </div>
                        </Col>
                        <Col sm="6">
                          <div className="box">
                            <div className="box-title dashboard">
                              <h3>Billing Address</h3>
                            </div>
                            <Row>
                              <Col sm="12">
                                {values?.useSameAsShipping ? (
                                  <address>
                                    <strong>Address line 1:</strong>{" "}
                                    {values?.address_1 || " "}
                                    <br />
                                    <strong>Address line 2:</strong>{" "}
                                    {values?.address_2 || " "}
                                    <br />
                                    <strong>Zip code:</strong>{" "}
                                    {values?.zip_code || " "}
                                    <br />
                                    <strong>City:</strong> {values.city || " "}
                                    <br />
                                    <strong>State:</strong>{" "}
                                    {values?.state || " "}
                                  </address>
                                ) : (
                                  <address>
                                    <strong>Address line 1:</strong>{" "}
                                    {values?.billing_address_1 || " "}
                                    <br />
                                    <strong>Address line 2:</strong>{" "}
                                    {values?.billing_address_2 || " "}
                                    <br />
                                    <strong>Zip code:</strong>{" "}
                                    {values?.billing_zip_code || " "}
                                    <br />
                                    <strong>City:</strong>{" "}
                                    {values?.billing_city || " "}
                                    <br />
                                    <strong>State:</strong>{" "}
                                    {values?.billing_state || " "}
                                  </address>
                                )}
                              </Col>
                            </Row>
                            <Button
                              onClick={() =>
                                router.push({
                                  pathname: router.pathname,
                                  query: { param1: "" },
                                })
                              }
                              type="link"
                            >
                              Update Address
                            </Button>
                          </div>
                        </Col>
                        <table className="table cart-table table-responsive-md">
                          <tfoot>
                            <tr>
                              <td>
                                <h3>Total to Pay :</h3>
                              </td>
                              <td>
                                <h2 className="carttotal">
                                  {symbol}
                                  {(cartTotal + shipCost)?.toFixed(2)}
                                </h2>
                              </td>
                            </tr>
                          </tfoot>
                        </table>
                      </Row>{" "}
                      <Button onClick={clickDetail}>Add More Items</Button>
                    </>
                  ) : (
                    <AddressForm form={form} />
                  )}
                </Col>
                <Col lg={"6"} sm="12" xs="12">
                  {cartItems && cartItems.length > 0 > 0 ? (
                    <div className="checkout-details">
                      {!router.query.param1 && (
                        <div className="order-box">
                          <Row className="title-box">
                            <Col xs={8}>
                              <div>Product</div>
                            </Col>
                            <Col xs={4}>
                              <div>Total</div>
                            </Col>
                          </Row>
                          {cartItems.map((item, index) => (
                            <Row className="qty" key={index}>
                              <Col xs={8}>
                                {item.name}× {item.qty}
                              </Col>
                              <Col xs={4}>
                                <span>${item?.total?.toFixed(2)}</span>
                              </Col>
                            </Row>
                          ))}
                          <Row className="sub-total">
                            <Col xs={8}>Subtotal </Col>
                            <Col xs={4}>
                              <span className="sub-total">
                                ${cartTotal?.toFixed(2)}
                              </span>
                            </Col>
                          </Row>
                          <Row className="sub-total">
                            <Col xs={8}>
                              <Select
                                defaultValue={true}
                                type="select"
                                onChange={(e) => setisStandardShip(e)}
                              >
                                <Select.Option value={true}>
                                  Standard Shipping
                                </Select.Option>
                                <Select.Option value={false}>
                                  Expedited Shipping
                                </Select.Option>
                              </Select>
                            </Col>
                            <Col xs={4}>
                              <span className="count">
                                {symbol}
                                {shipCost.toFixed(2)}
                              </span>
                            </Col>
                          </Row>
                          <Row className="total">
                            <Col xs={8}>
                              <b>Total</b>{" "}
                            </Col>
                            <Col xs={4}>
                              <b>${(shipCost + cartTotal)?.toFixed(2)}</b>
                            </Col>
                          </Row>
                          <button
                            onClick={handleFormSubmission}
                            className="btn-solid btn"
                          >
                            PROCEED TO PAYMENT
                          </button>
                        </div>
                      )}

                      {values && router.query.param1 && (
                        <div className="payment-box">
                          <span
                            style={{
                              fontSize: "25px",
                              color: "#2E5BA5",
                              fontWeight: "700",
                            }}
                          >
                            Payment Method
                          </span>
                          <div className="upper-box">
                            <div className="payment-options">
                              <ul>
                                {/* <li>
                                  <div className="radio-option stripe">
                                    <input
                                    <label htmlFor="payment-2">
                                    </label>
                                  </div>
                                </li> */}
                                <li>
                                  <div className="radio-option paypal responsive-radio-option-paypal">
                                    <input
                                      type="radio"
                                      name="payment-group"
                                      defaultChecked={true}
                                      id="payment-1"
                                      onClick={() => checkhandle("stripe")}
                                    />
                                    <label htmlFor="payment-1">
                                      <span
                                        style={{
                                          fontSize: "15px",
                                          minWidth: "135px",
                                        }}
                                      >
                                        Debit/Credit Card
                                      </span>
                                      <span className="image">
                                        <Media
                                          className="responsive-image-card"
                                          style={{
                                            // height: "30px",
                                            // width: "160px",
                                            backgroundPosition: "left bottom",
                                            backgroundSize: "contain",
                                            backgroundRepeat: "no-repeat",
                                            display: "inline-block",
                                            marginLeft: "5%",
                                            maxWidth: "300px",
                                            textAlign: "left",
                                            width: "90%",
                                          }}
                                          src={creditCardLogo.src}
                                          alt=""
                                        />
                                      </span>
                                    </label>
                                  </div>
                                </li>
                                <li>
                                  <div className="radio-option paypal responsive-radio2-option-paypal">
                                    <input
                                      type="radio"
                                      name="payment-group"
                                      id="payment-2"
                                      onClick={() => checkhandle("paypal")}
                                      style={{ top: "14%" }}
                                    />
                                    <label htmlFor="payment-2">
                                      <span className="image">
                                        <Media
                                          src={paypal.src}
                                          alt=""
                                          style={{
                                            backgroundPosition: "left bottom",
                                            backgroundSize: "contain",
                                            backgroundRepeat: "no-repeat",
                                            display: "inline-block",
                                            marginLeft: "1%",
                                            maxWidth: "300px",
                                            textAlign: "left",
                                            // width: "20%",
                                            width: "75px",
                                            height: "25px",
                                          }}
                                        />
                                        <span
                                          style={{
                                            fontSize: "15px",
                                            fontWeight: "400",
                                          }}
                                        >
                                          Speed through checkout. PayPal is the
                                          safer, easier way to pay.
                                        </span>
                                        <a
                                          href="https://about.pypl.com/about-us/default.aspx"
                                          target="_blank"
                                          rel="noopener noreferrer"
                                          style={{
                                            textDecoration: "underline",
                                            fontSize: "15px",
                                            fontWeight: "400",
                                          }}
                                        >
                                          What is PayPal?
                                        </a>{" "}
                                      </span>
                                    </label>
                                  </div>
                                </li>
                              </ul>
                            </div>
                          </div>
                          {cartTotal !== 0 ? (
                            <div className="text-end">
                              {payment === "paypal" ? (
                                <Paypal shipCost={shipCost} />
                              ) : (
                                router.query.param1 && (
                                  <button
                                    onClick={makePayment}
                                    className="btn-solid btn"
                                  >
                                    {loading ? <Spin /> : ""} Place Order
                                  </button>
                                )
                              )}
                            </div>
                          ) : (
                            ""
                          )}
                        </div>
                      )}
                    </div>
                  ) : (
                    ""
                  )}
                </Col>
              </Row>
            </Form>
          </div>
        </div>
      </Container>
    </section>
  );
};

export default CheckoutPage;
