import React, { useContext, useState } from "react";
import Link from "next/link";
import { useRouter } from "next/router";
import { Row, Col, Media, Modal, ModalBody, ModalHeader } from "reactstrap";
import { useEffect } from "react";
function isImageActive(imageUrl) {
  return new Promise((resolve) => {
    const img = new Image();

    img.onload = function () {
      // Image is successfully loaded
      resolve(true);
    };

    img.onerror = function () {
      // Image failed to load
      resolve(false);
    };

    img.src = imageUrl;
  });
}

const BrandSlider = ({ product }) => {
  const [isImageActiveState, setIsImageActiveState] = useState(false);

  useEffect(() => {
    const imageUrl = product?.image ? product?.image : "";

    isImageActive(imageUrl).then((result) => {
      setIsImageActiveState(result);
    });
  }, [product]);
  // eslint-disable-next-line
  const router = useRouter();

  const clickProductDetail = () => {
    router.push({
      pathname: `/brand/${product.id}`, // Specify your route
      query: { param1: product.name },
    });
  };

  return (
    <Link
      href={{
        pathname: `/brand/${product.id}`,
        query: { param1: product.name },
      }}
    >
      <div onClick={clickProductDetail} className="product-box product-wrap">
        <div className="img-wrapper responsive-img-wrapper-slider">
          <div className="front responsive-brand-logo-slider-slick" onClick={clickProductDetail}> 
            <Media
              src={
                isImageActiveState
                  ? product.image
                  : "/assets/images/no-image.png"
              }
              className="img-fluid catImage responsive-catImage-brand-slider"
              alt=""
            />
          </div>
          <div className="product-name-belowCatImage responsive-product-name-belowCatImage">
            {product?.name}
          </div>
        </div>
      </div>
    </Link>
  );
};

export default BrandSlider;
