import React, { useState, useContext } from "react";
import Link from "next/link";
import { Input, Col, Row } from "reactstrap";
import CartContext from "../helpers/cart";
import { useRouter } from "next/router";
import { isBusiness } from "./constant/menu";
import { UserContext } from "../helpers/loginContext/loginContext";
import { notification } from "antd";

const DetailsWithPrice = ({ item, stickyClass, needDetails }) => {
  const { user } = useContext(UserContext);

  const product = item;
  const context = useContext(CartContext);

  const [quantity, setQuantity] = useState(
    isBusiness(user) ? product.minimum_quantity : 1
  );
  const [stock, setStock] = useState(
    product.available_stock >= (isBusiness(user) ? product.minimum_quantity : 1)
      ? "In Stock"
      : "Out of Stock !"
  );
  const minusQty = () => {
    if (quantity > (isBusiness(user) ? product.minimum_quantity : 1)) {
      setQuantity(quantity - 1);
      setStock("In Stock");
    } else {
      notification.info({
        message: `Minimum Allowed`,
        description: "This is minimum selectable qty!",
        placement: "bottomRight",
      });
    }
  };

  const plusQty = (item) => {
    if (item.available_stock > quantity) {
      setQuantity(quantity + 1);
    } else {
      notification.info({
        message: `Out of Stock`,
        description: "This is maximum availbe stock!",
        placement: "bottomRight",
      });
    }
  };

  const router = useRouter();
  function calculateDiscountPercentage(originalPrice, discountedPrice) {
    if (
      originalPrice <= 0 ||
      (discountedPrice !== undefined &&
        (discountedPrice <= 0 || discountedPrice >= originalPrice))
    ) {
      // Invalid input, handle accordingly (return an error or handle as needed)
      return null;
    }

    // Check if discounted price is not given or is 0
    if (discountedPrice === undefined || discountedPrice === 0) {
      return 0;
    }

    // Check if prices are the same
    if (originalPrice === discountedPrice) {
      return 0;
    }

    // Calculate the discount percentage
    const discount = originalPrice - discountedPrice;
    const discountPercentage = (discount / originalPrice) * 100;

    // Round to two decimal places
    return Math.round(discountPercentage * 100) / 100;
  }
  const disc = calculateDiscountPercentage(
    product?.price,
    isBusiness(user) ? product?.wholesale_price : product?.discounted_price
  );

  const changeQty = (e) => {
    const newQuantity = parseInt(e.target.value);

    // Check if the input is a valid number
    if (!isNaN(newQuantity)) {
      // Check if the new quantity is within the allowed range

      if (item.available_stock >= newQuantity) {
        if (newQuantity < (isBusiness(user) ? product.minimum_quantity : 1)) {
          setQuantity(isBusiness(user) ? product.minimum_quantity : 1);
        } else setQuantity(newQuantity);
        setStock("In Stock");
      } else {
        setQuantity(item.available_stock);
        notification.error({
          message: `Out of Stock`,
          description: "This is maximum availbe stock!",
          placement: "bottomRight",
        });
      }
    }
    // If the input is not a valid number, you can handle it accordingly
  };
  const clickProductDetail = () => {
    router.push(`/product-details/${product.id}`);
  };
  return (
    <>
      <div className={`product-right ${stickyClass}`}>
        <Row style={{ alignItems: "center" }}>
          <Col lg="7">
            <h2 onClick={clickProductDetail}>
              {product.name} {product.part_number}
            </h2>
            <Row>
              <Col>
                <p>
                  Part Number:
                  <b>{product.part_number}</b>
                </p>
              </Col>
            </Row>
            <div className="border-product">
              <Row style={{ rowGap: "13px" }}>
                <Col
                  style={{
                    // textWrap: "nowrap",
                    display: "flex",
                    flexDirection: "column",
                    rowGap: "8px",
                  }}
                >
                  <Col className="pdesc">
                    <p>Part Description</p>
                  </Col>
                  <Col>
                    <p>Replaces</p>
                  </Col>
                  <Col>
                    <p>Manufacturer</p>
                  </Col>
                  {needDetails && (
                    <>
                      <Col>
                        <p>Details</p>
                      </Col>
                    </>
                  )}
                </Col>
                <Col
                  style={{
                    // textWrap: "nowrap",
                    display: "flex",
                    flexDirection: "column",
                    rowGap: "8px",
                  }}
                >
                  <Col className="pdesc">
                    <p>{product.description}</p>
                  </Col>

                  <Col>
                    <p>{product.replaces}</p>
                  </Col>

                  <Col>
                    <p>{product.manufacturer}</p>
                  </Col>
                  {needDetails && (
                    <>
                      <Col>
                        <p>
                          <Link href={`/product-details/${product.id}`}>
                            View More
                          </Link>
                        </p>
                      </Col>
                    </>
                  )}
                </Col>
              </Row>
            </div>
          </Col>
          <Col
            lg="5"
            style={{
              paddingTop: "10px",
              paddingBottom: "10px",
              paddingRight: "0px",
            }}
          >
            <div className="secprice">
              <h3
                style={{ color: "#e52222", display: "flex", alignItems: "end" }}
              >
                <b>
                  $
                  {isBusiness(user)
                    ? product?.wholesale_price?.toFixed(2)
                    : disc
                    ? product?.discounted_price?.toFixed(2)
                    : product?.price?.toFixed(2)}
                </b>
                {disc && (
                  <h4>
                    <p>
                      MSRP: <del>{product?.price?.toFixed(2)}</del>
                    </p>
                  </h4>
                )}
              </h3>
              {disc && (
                <p style={{ color: "green" }}>
                  you save: $
                  {isBusiness(user)
                    ? (product?.price - product?.wholesale_price)?.toFixed(2)
                    : (product?.price - product?.discounted_price)?.toFixed(2)}
                  ({disc?.toFixed(0)}
                  %)
                </p>
              )}

              <div className="product-description">
                <span className="instock-cls">{stock}</span>
                <div className="qty-box">
                  <div className="input-group">
                    <span className="input-group-prepend">
                      <button
                        type="button"
                        className="btn quantity-left-minus"
                        onClick={minusQty}
                        data-type="minus"
                        data-field=""
                      >
                        <i className="fa fa-angle-left"></i>
                      </button>
                    </span>
                    <Input
                      type="text"
                      name="quantity"
                      min={isBusiness(user) ? item.minimum_quantity : 1}
                      max={item.available_stock}
                      value={quantity}
                      disabled
                      // onChange={changeQty}
                      className="form-control input-number"
                    />
                    <span className="input-group-prepend">
                      <button
                        type="button"
                        className="btn quantity-right-plus"
                        onClick={() => plusQty(product)}
                        data-type="plus"
                        data-field=""
                      >
                        <i className="fa fa-angle-right"></i>
                      </button>
                    </span>
                  </div>
                  <div className="product-buttons-atc">
                    <button
                      className="btn btn-solid responsive-solid-btn"
                      disabled={stock != "In Stock"}
                      onClick={() => context.addToCart(product, quantity)}
                    >
                      <li
                        className="fa fa-shopping-cart"
                        style={{ marginRight: "5px", fontSize: "25px" }}
                      ></li>
                      add to cart
                    </button>
                  </div>
                </div>
              </div>

              <hr />
              <text style={{ fontSize: "10px" }}>
                Ships in 1-3 Business Days
              </text>
            </div>
          </Col>
        </Row>
      </div>
    </>
  );
};

export default DetailsWithPrice;
