import React, { useContext, useEffect, useState } from "react";
import { CardElement, useStripe, useElements } from "@stripe/react-stripe-js";
import { Button, Spinner } from "reactstrap";
import CartContext from "../../../helpers/cart";
import jwtAxios from "../../../utils/Apis";
import { UserContext } from "../../../helpers/loginContext/loginContext";
import { useRouter } from "next/router";
import { Spin } from "antd";
const getLocalItems = () => {
  try {
    const list = localStorage.getItem("orderData");
    if (list === null) {
      return {};
    } else {
      return JSON.parse(list);
    }
  } catch (err) {
    return {};
  }
};
const CheckoutForm = ({ values }) => {
  const router = useRouter();
  const cartContext = useContext(CartContext);
  const cartItems = cartContext.state;
  const cartTotal = cartContext.cartTotal;
  const { user } = useContext(UserContext);

  const [error, setError] = useState(null);
  const [loading, setLoading] = useState(false);

  const handleSubmit = async () => {
    try {
      setLoading(true);

      if (error) {
        setError(error.message);
      } else {
        let values = getLocalItems();

        values.cart = cartItems;
        values.appartment = "appartment";
        values.sub_total = cartTotal + values.ship_cost;
        if (user) {
          values.user = { id: user.id };
          values.user_id = user.id;
          values.id = user.id;
        }
        // console.log(token, values);
        const response = await jwtAxios.post(`order/create`, values);

        const orderId = response?.data?.data?.id;
        if (response.data?.success && orderId) {
          router.push({
            pathname: `/page/order-success/${orderId}`,
          });
        }
        // console.log(token, response);
      }
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    handleSubmit();
  }, [user]);

  return <Spin size="large" />;
};

export default CheckoutForm;
