import React, { useState, useEffect, useContext } from "react";
import { Button, Container, Input, Row, FormGroup, Col } from "reactstrap";
import axios from "axios";
import jwtAxios from "../utils/Apis";
import FilterContext from "../helpers/filter/FilterContext";
import SelectVehicleModal from "./selectVehicleModal";

import { useRouter } from "next/router";
import { notification, Popover, List, Space, Radio, Modal } from "antd";

const Mainbannerleft = () => {
   const [open, setOpen] = useState(false);
  const { vehicles, setVehicles, setSelectedVehicle, selectedVehicle } =
    useContext(FilterContext);
  const [companies, setCompanies] = useState([]);
  const [selectedCompany, setSelectedCompany] = useState("");
  const [models, setModels] = useState([]);
  const [selectedModel, setSelectedModel] = useState("");
  const [years, setYears] = useState([]);
  const [selectedYear, setSelectedYear] = useState("");
  const router = useRouter();
  useEffect(() => {
    // Fetch the list of companies when the component mounts
    const fetchCompanies = async () => {
      try {
        const response = await jwtAxios.get("vehicle/allCompanies"); // Replace with your actual API endpoint
        console.log(response.data);
        setCompanies(response.data);
      } catch (error) {
        console.error("Error fetching companies:", error);
      }
    };

    fetchCompanies();
  }, []);

  const handleCompanyChange = async (company) => {
    // Fetch models based on the selected company
    setSelectedCompany(company);
    try {
      const response = await jwtAxios.get(`vehicle/allModels/${company}`); // Replace with your actual API endpoint
      setModels(response.data);
    } catch (error) {
      console.error("Error fetching models:", error);
    }
  };

  const handleModelChange = async (model) => {
    // Fetch years based on the selected model
    setSelectedModel(model);
    try {
      const response = await jwtAxios.get(`vehicle/allYears/${model}`); // Replace with your actual API endpoint
      setYears(response.data);
    } catch (error) {
      console.error("Error fetching years:", error);
    }
  };

  const handleYearChange = (year) => {
    // Handle the selected year
    setSelectedYear(year);
  };

  const handleFindParts = async () => {
    if (selectedVehicle) {
      router.push(`/shop/parts-by-selected-vehicle`);
    } else {
      if (!selectedCompany) {
        alert("Please select a company.");
        return;
      }
      if (!selectedModel) {
        alert("Please select a model.");
        return;
      }
      if (!selectedYear) {
        alert("Please select a year.");
        return;
      }
      try {
        const response = await jwtAxios.get(
          `vehicle/searchVehicle/${selectedYear}/${selectedModel}/${selectedCompany}`
        ); // Replace with your actual API endpoint
        // alert(`${JSON.stringify(response.data)}`);

        if (vehicles?.find((sVehicle) => sVehicle.id == response.data.id)) {
          message.info("Already Selected");
        } else {
          setSelectedVehicle(response.data.id);
          notification.success({
            message: `Vehicle Added`,
            description: "Vehicle Added Successfully in Garage!",
            placement: "bottomRight",
          });
          setVehicles([...vehicles, response.data]);
          router.push(`/shop/parts-by-selected-vehicle`);
        }
      } catch (error) {
        console.error("Error fetching years:", error);
      }
    }
  };

  return (
    <>
      <div style={{ width: "100%" }}>
        <Container>
          <Row>
            <Col
              sm="12"
              style={{
                border: "2px solid #2E5BA5",
                padding: "0px",
              }}
            >
              {/* <div> */}
              <div style={{ backgroundColor: "#2E5BA5" }}>
                <h3
                  style={{
                    paddingTop: "5px",
                    paddingBottom: "5px",
                    paddingLeft: "5px",
                    margin: "0px",
                    fontSize: "1.36em",
                    fontWeight: "bold",
                    color: "white",
                    textAlign: "center",
                  }}
                >
                  Shop For Toyota Parts
                </h3>
              </div>
              <Row style={{ justifyContent: "center" }} className="orrow-web">
                {!selectedVehicle && <div className="banneror">OR</div>}
              </Row>
              <Row
                style={{ justifyContent: "center" }}
                className="orrow-mobile"
              >
                {!selectedVehicle && <div className="banneror-m">OR</div>}
              </Row>

              <div className="mainbannerleft">
                <Col
                  sm="6"
                  style={{
                    paddingLeft: "20px",
                    paddingRight: "20px",
                    paddingBottom: "20px",
                    backgroundColor: "#D3EAFF",
                    paddingTop: "15px",
                    minHeight: "264px",
                    display: "flex",
                    alignItems: "center",
                    justifyContent: "center",
                    // width:"100%"
                  }}
                  className="innerbanner"
                >
                  <div
                  // style={{ marginTop: "15px" }}
                  >
                    <h4 style={{ fontWeight: 700 }}>
                      {selectedVehicle ? "My Vehicle" : "Select Vehicle By VIN"}
                    </h4>
                    {selectedVehicle && (
                      <h5
                        style={{
                          color: "#333333",
                          fontWeight: 700,
                          textTransform: "capitalize",
                        }}
                      >
                        {
                          vehicles?.find(
                            (sVehicle) => sVehicle.id == selectedVehicle
                          )?.company
                        }
                        {","}{" "}
                        {
                          vehicles?.find(
                            (sVehicle) => sVehicle.id == selectedVehicle
                          )?.model
                        }
                        {","}{" "}
                        {
                          vehicles?.find(
                            (sVehicle) => sVehicle.id == selectedVehicle
                          )?.year
                        }
                      </h5>
                    )}
                    {!selectedVehicle && (
                      <>
                        {" "}
                        <Input
                          id="vinInput"
                          name="vinInput"
                          className="bannerinput"
                          placeholder="Enter the VIN for this vehicle"
                        />
                      
                        <Button
                          className="bannerbutton"
                          onClick={handleFindParts}
                        >
                          Find My Parts
                        </Button>
                       
                        <p style={{ marginTop: "70px" }}>
                          For the most accurate results, search by your VIN
                          (vehicle identification number).
                        </p>
                      </>
                    )}
                  </div>
                </Col>

                <Col
                  sm="6"
                  style={{
                    padding: "20px",
                    backgroundColor: "#DCF2FF",
                    minHeight: "264px",
                    display: "flex",
                    alignItems: "center",
                    justifyContent: "center",
                    // width:"100%"
                  }}
                  className="innerbanner"
                >
                  <div
                  // style={{  marginLeft: "20px" }}
                  >
                    <h4 style={{ fontWeight: 700 }}>
                      {selectedVehicle ? "" : "Select Vehicle By Model"}
                    </h4>
                    {!selectedVehicle && (
                      <FormGroup>
                        <Input
                          className="bannerinput2"
                          id="companySelect"
                          style={{ textTransform: "capitalize" }}
                          name="companySelect"
                          type="select"
                          onChange={(e) => handleCompanyChange(e.target.value)}
                        >
                          <option>--Select Company--</option>
                          {companies?.map((company) => (
                            <option
                              style={{ textTransform: "capitalize" }}
                              key={company}
                              value={company}
                            >
                              {company}
                            </option>
                          ))}
                        </Input>
                        <Input
                          id="modelSelect"
                          name="modelSelect"
                          style={{ textTransform: "capitalize" }}
                          type="select"
                          className="bannerinput2"
                          onChange={(e) => handleModelChange(e.target.value)}
                          disabled={!selectedCompany} // Disable if no company selected
                        >
                          <option>--Select Model--</option>
                          {models?.map((model) => (
                            <option
                              style={{ textTransform: "capitalize" }}
                              key={model}
                              value={model}
                            >
                              {model}
                            </option>
                          ))}
                        </Input>
                        <Input
                          id="yearSelect"
                          name="yearSelect"
                          type="select"
                          style={{ textTransform: "capitalize" }}
                          className="bannerinput2"
                          defaultValue="--Select Year--"
                          disabled={!selectedModel || !selectedCompany}
                          onChange={(e) => handleYearChange(e.target.value)}
                        >
                          <option>--Select Year--</option>
                          {years?.map((year) => (
                            <option
                              style={{ textTransform: "capitalize" }}
                              key={year}
                              value={year}
                            >
                              {year}
                            </option>
                          ))}
                        </Input>
                      </FormGroup>
                    )}
                    <div className="findbtn">
                      {selectedVehicle && (
                        <li className="findbtntext">
                          <p
                            style={{
                              paddingLeft: "5px",
                              color: "#2E5BA5",
                              fontSize: "14px",
                              textDecoration: "underline",
                            }}
                          >
                            <Popover
                              // open={open}
                              content={
                                <div
                                  style={{ width: "600px" }}
                                  className="garage"
                                >
                                  {" "}
                                  <List
                                    bordered={false}
                                    header={<b>My Vehicle List</b>}
                                    footer={
                                      <Space>
                                        <button
                                          class="btn btn-solid"
                                          // type="primary"
                                          onClick={() => setOpen(true)}
                                        >
                                          Add New Vehicle
                                        </button>
                                        <Button
                                          type="link"
                                          onClick={() => {
                                            setVehicles([]);
                                            setSelectedVehicle(null);
                                            router.push(`/`);
                                          }}
                                          style={{
                                            color: "#2E5BA5",
                                            backgroundColor: "white",
                                            border: "none",
                                          }}
                                        >
                                          Clear All
                                        </Button>
                                      </Space>
                                    }
                                    size="small"
                                    dataSource={vehicles}
                                    renderItem={(item) => (
                                      <List.Item
                                        actions={[
                                          <i
                                            className="fa fa-remove"
                                            aria-hidden="true"
                                            key="list-loadmore-more"
                                            onClick={() => {
                                              setVehicles((pre) =>
                                                pre.filter((a) => a !== item)
                                              );
                                              if (item.id == selectedVehicle)
                                                setSelectedVehicle(null);
                                              router.push(`/`);
                                            }}
                                          ></i>,
                                        ]}
                                      >
                                        <List.Item.Meta
                                          title={
                                            <Radio
                                              checked={
                                                selectedVehicle == item.id
                                              }
                                              onChange={(e) =>
                                                setSelectedVehicle(item.id)
                                              }
                                            >
                                              <span
                                                style={{
                                                  textTransform: "capitalize",
                                                }}
                                              >
                                                {`${item.company} ${item.model} ${item.year}`}
                                              </span>
                                            </Radio>
                                          }
                                        />
                                      </List.Item>
                                    )}
                                  />
                                </div>
                              }
                              // title="Title"
                              placement="bottom"
                            >
                              Change Vehicle
                            </Popover>
                          </p>
                        </li>
                      )}
                      <Button
                        className="bannerbutton"
                        onClick={handleFindParts}
                      >
                        {" "}
                        Find My Parts{" "}
                      </Button>
                    </div>
                  </div>
                </Col>
              </div>
              {/* </div> */}
              {open && (
                <Modal
                  open={open}
                  onCancel={() => setOpen(false)}
                  title={"Select Vehicle"}
                  width={800}
                  footer={null}
                  onOk={() => setOpen(false)}
                  // title={null}
                >
                  <SelectVehicleModal setOpen={setOpen} />
                </Modal>
              )}
            </Col>
          </Row>
        </Container>
      </div>
    </>
  );
};

export default Mainbannerleft;
