import React, { useState, useContext, useEffect } from "react";
import { Col, Row, Media, Button, Spinner } from "reactstrap";
import SubCatBox from "./common/product-box/SubCatBox";
import { useRouter } from "next/router";
import PostLoader from "./common/PostLoader";
import errorHandler from "../utils/errorHandler";
import jwtAxios from "../utils/Apis";
import { Divider } from "antd";
import BrandBox from "./common/product-box/BrandBox";

const ProductList = ({ colClass, layoutList }) => {
  const router = useRouter();
  const [grid, setGrid] = useState(colClass);
  const [layout, setLayout] = useState(layoutList);
  const [data, setData] = useState(null);
  const [brandData, setBrandData] = useState(null);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    // console.log(data, "data");
    const fetchData = async () => {
      try {
        setIsLoading(true);
        // const response = await jwtAxios.get(`product/getAllProductsByCategory`);
        const response = await jwtAxios.get(`vehicle/allCategories`);
        setData(response.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };
    fetchData();
    const fetchBrands = async () => {
      try {
        setIsLoading(true);
        // const response = await jwtAxios.get(`product/getAllProductsByCategory`);
        const response = await jwtAxios.get(`getAllBrand`);
        setBrandData(response.data.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };
    fetchBrands();
  }, []);
  return (
    <Col
      className="collection-content"
      style={{
        background: "#F4F4F4",
        paddingLeft: "25px",
        paddingRight: "25px",
      }}
    >
      <div className="page-main-content">
        <Row>
          <Col sm="12">
            <div className="top-banner-wrapper">
              <div className="top-banner-content small-section">
                <h4>Popular Genuine Parts and Accessories</h4>
              </div>
            </div>

            <div className="collection-product-wrapper ">
              {!data || data.length === 0 || isLoading ? (
                <div className="row mx-0 margin-default mt-4">
                  <div className="col-xl-3 col-lg-4 col-6">
                    <PostLoader />
                  </div>
                  <div className="col-xl-3 col-lg-4 col-6">
                    <PostLoader />
                  </div>
                  <div className="col-xl-3 col-lg-4 col-6">
                    <PostLoader />
                  </div>
                  <div className="col-xl-3 col-lg-4 col-6">
                    <PostLoader />
                  </div>
                </div>
              ) : (
                data?.map((category, i) => (
                  <div key={i}>
                    <h4 className="categorysection">{category.name}</h4>
                    <div className={`product-wrapper-grid ${layout}`}>
                      <Row>
                        {category &&
                          category.sub_categories &&
                          category.sub_categories
                            .slice(0, 8)
                            ?.map((product, i) => (
                              <div className={grid} key={i}>
                                <div className="product">
                                  <div>
                                    <SubCatBox
                                      categoryId={category.id}
                                      des={true}
                                      product={product}
                                      cartClass="cart-info cart-wrap"
                                    />
                                  </div>
                                </div>
                              </div>
                            ))}
                      </Row>
                    </div>
                    <div style={{ display: "flex", justifyContent: "center" }}>
                      <Button
                        onClick={() =>
                          router.push({
                            pathname: `/page/category/${category.id}`, // Specify your route
                            query: { param1: category.name },
                          })
                        }
                        className="btn btn-solid catbtn"
                      >
                        View More
                      </Button>
                    </div>
                  </div>
                ))
              )}
            </div>
          </Col>
        </Row>
      </div>
    </Col>
  );
};

export default ProductList;
