import React, { useContext, useEffect, useState } from "react";
import { Container, Row, Col, Media, Modal, ModalBody } from "reactstrap";
import { useQuery } from "@apollo/client";
import { gql } from "@apollo/client";
import { CurrencyContext } from "../helpers/Currency/CurrencyContext";
import CartContext from "../helpers/cart";
import { WishlistContext } from "../helpers/wishlist/WishlistContext";
import { CompareContext } from "../helpers/Compare/CompareContext";
import { useRouter } from "next/router";
import jwtAxios from "../utils/Apis";
import errorHandler from "../utils/errorHandler";
import { Spin } from "antd";
import ProductImage from "./ProductImage";

const GET_PRODUCTS = gql`
  query products($type: _CategoryType!, $indexFrom: Int!, $limit: Int!) {
    products(type: $type, indexFrom: $indexFrom, limit: $limit) {
      items {
        id
        title
        description
        type
        brand
        category
        price
        new
        stock
        sale
        discount
        variants {
          id
          sku
          size
          color
          image_id
        }
        images {
          image_id
          id
          alt
          src
        }
      }
    }
  }
`;

const ProductSection = () => {
  const router = useRouter();
  const curContext = useContext(CurrencyContext);
  const wishlistContext = useContext(WishlistContext);
  const compareContext = useContext(CompareContext);
  const symbol = curContext.state.symbol;
  const currency = curContext.state;
  const cartCtx = useContext(CartContext);
  const addToCart = cartCtx.addToCart;
  const quantity = cartCtx.quantity;
  const plusQty = cartCtx.plusQty;
  const minusQty = cartCtx.minusQty;
  const setQuantity = cartCtx.setQuantity;
  const [selectedProduct, setSelectedProduct] = useState();
  const [modal, setModal] = useState(false);
  const toggle = () => setModal(!modal);
  const uniqueTags = [];

  const changeQty = (e) => {
    setQuantity(parseInt(e.target.value));
  };

  const id = router.query.id;

  const [product, setProduct] = useState(null);
  const [isLoading, setIsLoading] = useState(false);

  useEffect(() => {
    // console.log(data, "data");
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(`product/find/${id}`);
        setProduct(response.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };
    if (id) {
      fetchData();
    }
  }, [id]);
  // const image1Url = JSON.parse(product?.images);
  return (
    <section className="section-b-space ratio_asos">
      <Container>
        <Row>
          <Col className="product-related">
            <h2>related{product.name} products</h2>
          </Col>
        </Row>
        <Row className="search-product">
          {!product || isLoading ? (
            <Spin size="large" />
          ) : (
            <>
              {product && (
                <Col xl="2" md="4" sm="6">
                  <div className="product-box">
                    <div className="img-wrapper">
                      <div className="front">
                        <a href={null}>
                          {/* <Media
                            src={
                              product?.images
                                ? JSON.parse(product?.images)[0]?.image1
                                : "/assets/images/no-image.png"
                            }
                            className="img-fluid blur-up lazyload bg-img"
                            alt=""
                          /> */}
                          <ProductImage product={product} />
                        </a>
                      </div>

                      <div className="cart-info cart-wrap">
                        <button
                          data-toggle="modal"
                          data-target="#addtocart"   
                          title="Add to cart"
                          onClick={() => addToCart(product, quantity)}
                        >
                          <i className="fa fa-shopping-cart"></i>
                        </button>
                        <a
                          href="#"
                          onClick={() => wishlistContext.addToWish(product)}
                          title="Add to Wishlist"
                        >
                          <i className="fa fa-heart" aria-hidden="true"></i>
                        </a>
                      </div>
                    </div>
                    <div className="product-detail">
                      <div className="rating">
                        <i className="fa fa-star"></i>{" "}
                        <i className="fa fa-star"></i>{" "}
                        <i className="fa fa-star"></i>{" "}
                        <i className="fa fa-star"></i>{" "}
                        <i className="fa fa-star"></i>
                      </div>
                      <a href={null}>
                        <h6>{product.name}</h6>
                      </a>
                      <h4>{product?.discounted_price?.toFixed(2)}</h4>
                      <ul className="color-variant">
                        <li className="bg-light0"></li>
                        <li className="bg-light1"></li>
                        <li className="bg-light2"></li>
                      </ul>
                    </div>
                  </div>
                </Col>
              )}
            </>
          )}
        </Row>
      </Container>
    </section>
  );
};

export default ProductSection;
