import React, { createContext, useState, useEffect } from "react";
import Cookie from "js-cookie";
import { setAuthToken } from "../../utils/Apis";

export const UserContext = createContext({});

export const UserContextProvider = (props) => {
  const [user, setUser] = useState({});

  useEffect(() => {
    const userInfo = Cookie.get("userInfo");
    const token = Cookie.get("token");

    if (token && userInfo) {
      setAuthToken(token);
      setUser(JSON.parse(userInfo)); // Parse the user information if stored as a JSON string
    }
  }, []);

  // Add a function to clear user data when needed
  const clearUserData = () => {
    Cookie.remove("userInfo");
    Cookie.remove("token");
    setAuthToken(null);
    setUser({});
  };

  return (
    <UserContext.Provider
      value={{
        user,
        setUser,
        clearUserData,
      }}
    >
      {props.children}
    </UserContext.Provider>
  );
};
