import React, { useEffect, useState } from "react";
import DetailsWithPrice from "../../components/detail-price.js";
import { Empty, Spin } from "antd";
import { Row, Col, Container } from "reactstrap";
import jwtAxios from "../../utils/Apis.js";
import { useRouter } from "next/router.js";
import errorHandler from "../../utils/errorHandler.js";
import CommonLayout from "../../components/shop/common-layout.js";
import ProductImage from "../../components/ProductImage.js";
import Link from "next/link.js";
const Marketplace = () => {
  const router = useRouter();
  const id = router.query.id;
  const param1 = router.query.param1;
  const [products, setProducts] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  useEffect(() => {
    // console.log(data, "data");
    const fetchData = async () => {
      try {
        setIsLoading(true);
        const response = await jwtAxios.get(`productsByBrand/${id}`);
        setProducts(response?.data);
        setIsLoading(false);
      } catch (error) {
        errorHandler(error);
        setIsLoading(false);
      }
    };

    if (id) {
      fetchData();
    }
  }, [id]);

 
  return (
    <CommonLayout parent="Home" title={`Brand>${param1}`}>
      <section className="login-page section-b-space">
        {isLoading ? (
          <Container style={{ marginBottom: "100px" }}>
            <Row style={{ justifyContent: "center" }}>
              <Spin size="large" />
            </Row>
          </Container>
        ) : (
          <Container>
            {products?.length === 0 && <Empty />}
            {products?.map((product, i) => (
              <Row
                key={i}
                style={{
                  justifyContent: "center",
                  marginTop: "40px",
                  marginBottom: "40px",
                }}
              >
                <Col sm="12" xl="12">
                  {isLoading ? (
                    <Spin />
                  ) : (
                    <Row>
                      <Col
                        lg="3"
                        className="product-thumbnail"
                        style={{
                          justifyContent: "center",
                          display: "flex",
                          alignItems: "center",
                        }}
                      >
                        <Link href={"/product-details/" + product.id}>
                          <ProductImage product={product} />
                        </Link>
                      </Col>
                      <Col lg="9" className="rtl-text product-ps">
                        <DetailsWithPrice item={product} needDetails={true} />
                      </Col>
                    </Row>
                  )}
                </Col>
              </Row>
            ))}
          </Container>
        )}
      </section>
    </CommonLayout>
  );
};

export default Marketplace;
