import React, { useContext, useEffect, useState } from "react";
import CommonLayout from "../../../components/shop/common-layout";
import { Container, Row, Col } from "reactstrap";
import {
  Button,
  Checkbox,
  Divider,
  Drawer,
  Empty,
  Form,
  Image,
  Input,
  Select,
  Space,
  Table,
  message,
  notification,
} from "antd";
import jwtAxios from "../../../utils/Apis";
import errorHandler from "../../../utils/errorHandler";
import dayjs from "dayjs";
import successHandler from "../../../utils/successHandler";
import { UserContext } from "../../../helpers/loginContext/loginContext";
import { useRouter } from "next/router";
import PhoneCodes from "../../../components/constant/Codes";

const Dashboard = () => {
  const { user, clearUserData } = useContext(UserContext);
  const [accountInfo, setAccountInfo] = useState(false);
  const [whatIsClick, setWhatIsClick] = useState("My Account");
  const [selectedSchool, setSelectedSchool] = useState();
  const [userModel, setUserModel] = useState(false);
  const [data, setData] = useState([]);
  const [address, setAddress] = useState([]);
  const [loading, setLoading] = useState(false);
  const [whatLoading, setWhatLoading] = useState(null);
  const router = useRouter();
  const [isFetch, setIsFetch] = useState(false);
  const fetchData = async () => {
    try {
      setLoading(true);
      const response = await jwtAxios.get(`/uorder/${user.id}`);
      console.log(response);
      setData(response.data);
      setLoading(false);
    } catch (error) {
      errorHandler(error);
      setLoading(false);
    }
  };
  const fetchAddress = async () => {
    try {
      setLoading(true);
      const response = await jwtAxios.get(`getAllAddress/${user.id}`);
      setAddress(response.data);
      setLoading(false);
    } catch (error) {
      errorHandler(error);
      setLoading(false);
    }
  };
  const removeAddress = async (addressId) => {
    try {
      setLoading(true);
      setWhatLoading(`remove-${addressId}`);
      const response = await jwtAxios.delete(`address/delete/${addressId}`);
      fetchAddress();
      setLoading(false);
      setWhatLoading(null);
    } catch (error) {
      errorHandler(error);
    }
  };
  const removeAddressAll = async () => {
    try {
      setLoading(true);
      setWhatLoading(`remove-all`);
      const response = await jwtAxios.delete(`address/deleteAll/${user.id}`);
      fetchAddress();
      setLoading(false);
      setWhatLoading(null);
    } catch (error) {
      errorHandler(error);
    }
  };

  useEffect(() => {
    if (user?.id) {
      fetchData();
      fetchAddress();
    }
  }, [user]);
  //  const router=useRouter()

  useEffect(() => {
    if (!user.id) router.push("/");
  }, [user]);
  useEffect(() => {
    if (!user.id) router.push("/");
  }, []);

  const [form] = Form.useForm();
  useEffect(() => {
    form.setFieldsValue({ ...selectedSchool });
  }, [user, userModel]);
  function padIdWithZeros(cuId) {
    // Ensure id is a string and convert it to a number
    cuId = Number(cuId).toString();

    // Calculate the number of zeros to pad
    const zerosToAdd = 5 - cuId.length;

    // Pad the id with zeros
    const paddedId = "0".repeat(zerosToAdd) + cuId;

    // Prefix with "INV-"
    const finalId = "INV-" + paddedId;

    return finalId;
  }
  return (
    <CommonLayout parent="home" title="Dashboard">
      {/* <section className="section-b-space login-page"> */}
      {user && (
        <Container>
          <Row>
            <Col lg="3">
              {window.innerWidth <= 991 ? (
                <div
                  className="account-sidebar"
                  onClick={() => setAccountInfo(!accountInfo)}
                >
                  <a className="popup-btn">My account</a>
                </div>
              ) : (
                ""
              )}
              <div
                className="dashboard-left"
                style={accountInfo ? { left: "0px" } : {}}
              >
                <div
                  className="collection-mobile-back"
                  onClick={() => setAccountInfo(!accountInfo)}
                >
                  <span className="filter-back">
                    <i className="fa fa-angle-left" aria-hidden="true"></i> back
                  </span>
                </div>
                <div className="block-content">
                  <Divider orientation="left">My Account</Divider>
                  <ul>
                    <li
                      className={whatIsClick == "My Account" ? "active" : ""}
                      onClick={() => {
                        setWhatIsClick("My Account");
                        setIsFetch(false);
                      }}
                    >
                      <a href={null}>My Account</a>
                    </li>
                    <li
                      className={whatIsClick == "school" ? "active" : ""}
                      onClick={() => {
                        setWhatIsClick("school");
                        setIsFetch(true);
                      }}
                    >
                      <a href={null}>My Orders</a>
                    </li>
                    <li
                      className={whatIsClick == "addressBook" ? "active" : ""}
                      onClick={() => {
                        setWhatIsClick("addressBook");
                      }}
                    >
                      <a href={null}>Address Book</a>
                    </li>

                    <li
                      className={whatIsClick == "password" ? "active" : ""}
                      onClick={() => {
                        setWhatIsClick("password");
                        setIsFetch(false);
                      }}
                    >
                      <a href={null}>Change Password</a>
                    </li>
                    <li
                      className={whatIsClick == "logout" ? "active" : ""}
                      onClick={() => {
                        clearUserData();
                        setIsFetch(false);
                        setWhatIsClick("logout");
                        router.push("/");
                      }}
                    >
                      <a href={null}>Log Out</a>
                    </li>
                  </ul>

                  <Divider orientation="left">Help</Divider>
                  <ul>
                    <li
                      className={""}
                      onClick={() => {
                        router.push("/page/contact");
                      }}
                    >
                      <a href={null}>Contact Us</a>
                    </li>
                    <li
                      className={""}
                      onClick={() => {
                        router.push("/shop/privacy-policy");
                      }}
                    >
                      <a href={null}>Policies</a>
                    </li>
                    <li
                      className={""}
                      onClick={() => {
                        router.push("/help-center");
                      }}
                    >
                      <a href={null}>Help Center</a>
                    </li>
                  </ul>
                </div>
              </div>
            </Col>
            <Col lg="9">
              {whatIsClick == "school" && (
                <Table
                  scroll={{ x: 100 }}
                  size="small"
                  columns={[
                    {
                      title: "Order Id",
                      render: (_, record) => padIdWithZeros(record.id),
                    },
                    { title: "Order Status", dataIndex: "name" },

                    {
                      title: "Order Date",
                      render: (_, record) =>
                        dayjs(record.createdAt).format("MM-DD-YYYY"),
                      className: "invcell",
                    },
                    {
                      title: "Deleivery Date",
                      render: (_, record) => "-",
                    },
                    {
                      title: "Sub Total",
                      render: (_, record) => record.total?.toFixed(2),
                    },
                  ]}
                  dataSource={data}
                  rowKey={(e) => e.id}
                  expandable={{
                    expandedRowRender: (record) => (
                      <>
                        <Row>
                          <Col sm="6">
                            <div className="box">
                              <div className="box-title dashboard">
                                <h3>Shipping Address</h3>
                              </div>
                              <Row>
                                <Col sm="6">
                                  <address>
                                    <strong>Company:</strong>{" "}
                                    {record.company || " "}
                                    <br />
                                    <strong>Address line 1:</strong>{" "}
                                    {record.address_1 || " "}
                                    <br />
                                    <strong>Address line 2:</strong>{" "}
                                    {record.address_2 || " "}
                                    <br />
                                    <strong>Country:</strong>{" "}
                                    {record.country || " "}
                                    <br />
                                    <strong>Zip code:</strong>{" "}
                                    {record.zip_code || " "}
                                    <br />
                                    <strong>Phone:</strong>{" "}
                                    {record.phone || " "}
                                    <br />
                                    <strong>State/City:</strong>{" "}
                                    {record.state_city || " "}
                                  </address>
                                </Col>
                              </Row>
                            </div>
                          </Col>
                          <Col sm="6">
                            <div className="box">
                              <div className="box-title dashboard">
                                <h3>Order Items</h3>
                              </div>
                              <Row className="qty">
                                <Col xs={6}>
                                  <strong>Name</strong>
                                </Col>
                                <Col xs={3} style={{ textAlign: "center" }}>
                                  <strong>Qty</strong>
                                </Col>
                                <Col xs={3}>
                                  <strong>Price</strong>
                                </Col>
                                <hr />
                              </Row>
                              {record?.order_items?.map((item, index) => (
                                <Row className="qty" key={index}>
                                  <Col xs={6}>{item.product.name}</Col>
                                  <Col xs={3} style={{ textAlign: "center" }}>
                                    {item.quantity}
                                  </Col>
                                  <Col xs={3}>${item?.price?.toFixed(2)}</Col>
                                  <hr />
                                </Row>
                              ))}
                            </div>
                          </Col>
                        </Row>
                      </>
                    ),
                  }}
                  loading={loading}
                />
              )}

              {whatIsClick == "password" && (
                <div style={{ width: "400px" }}>
                  <Form
                    layout="vertical"
                    onFinish={async (values) => {
                      try {
                        values.id = user?.id;
                        const response = await jwtAxios.post(
                          `updatePassword/${user.id}`,
                          values
                        );
                        notification.success({
                          message: `Password Updated`,
                          description: "Your password successfully updated",
                          placement: "bottomRight",
                        });
                        setWhatIsClick("My Account");
                      } catch (error) {
                        errorHandler(error);
                      }
                    }}
                  >
                    <Form.Item
                      name="current_password"
                      label="Current Password"
                      rules={[
                        {
                          required: true,
                          message: "Please input your current_password!",
                        },
                      ]}
                    >
                      <Input.Password />
                    </Form.Item>
                    <Form.Item
                      name="password"
                      label="New Password"
                      rules={[
                        {
                          required: true,
                          message: "Please input your password!",
                        },
                      ]}
                    >
                      <Input.Password />
                    </Form.Item>
                    <Form.Item
                      name="new_password"
                      dependencies={["password"]}
                      label="New Confirm Passowrd"
                      hasFeedback
                      rules={[
                        {
                          required: true,
                          message: "Please confirm your password!",
                        },
                        ({ getFieldValue }) => ({
                          validator(_, value) {
                            if (!value || getFieldValue("password") === value) {
                              return Promise.resolve();
                            }
                            return Promise.reject(
                              new Error(
                                "The new password that you entered do not match!"
                              )
                            );
                          },
                        }),
                      ]}
                    >
                      <Input.Password />
                    </Form.Item>
                    <Button
                      className="btn btn-solid"
                      htmlType="submit"
                      style={{ paddingBottom: "30px" }}
                      // loading={whatLoading == "register" && loading}
                    >
                      Update
                    </Button>
                  </Form>
                </div>
              )}
              {whatIsClick == "My Account" && (
                <div className="dashboard-right">
                  <div className="dashboard">
                    <div className="page-title">
                      <h2>My Dashboard</h2>
                    </div>
                    <div className="welcome-msg">
                      <p>Hello, {user?.first_name} !</p>
                    </div>
                    <div className="box-account box-info">
                      <div className="box-head">
                        <h2>Account Information</h2>
                      </div>
                      <Row>
                        <Col sm="6">
                          <div className="box">
                            <div className="box-title">
                              <h3>Contact Information</h3>
                              {/* <a
                                  href={null}
                                  onClick={() => {
                                    setSelectedSchool(user);
                                    setUserModel(true);
                                  }}
                                >
                                  Edit
                                </a> */}
                            </div>
                            <div className="box-content">
                              <h6>
                                {user?.first_name} {user?.last_name}
                              </h6>
                              <h6>{user?.email}</h6>
                              <h6>
                                <Button
                                  type="link"
                                  onClick={() => {
                                    setIsFetch(false);
                                    setWhatIsClick("password");
                                  }}
                                  style={{ color: "#2E5BA5" }}
                                >
                                  <b> Change Password</b>
                                </Button>
                              </h6>
                            </div>
                          </div>
                        </Col>
                        {/* <Col sm="6">
                            <div className="box">
                              <div className="box-title">
                                <h3>Newsletters</h3>
                                <a href="#">Edit</a>
                              </div>
                              <div className="box-content">
                                <p>
                                  You are currently not subscribed to any
                                  newsletter.
                                </p>
                              </div>
                            </div>
                          </Col> */}
                      </Row>
                      {/* <div>
                          <div className="box">
                            <div className="box-title">
                              <h3>Address Book</h3>
                              <a href="#">Manage Addresses</a>
                            </div>
                            <Row>
                              <Col sm="6">
                                <h6>Default Billing Address</h6>
                                <address>
                                  You have not set a default billing address.
                                  <br />
                                  <a href="#">Edit Address</a>
                                </address>
                              </Col>
                              <Col sm="6">
                                <h6>Default Shipping Address</h6>
                                <address>
                                  You have not set a default shipping address.
                                  <br />
                                  <a href="#">Edit Address</a>
                                </address>
                              </Col>
                            </Row>
                          </div>
                        </div> */}
                    </div>
                  </div>
                </div>
              )}
              {whatIsClick == "addressBook" && (
                <div className="dashboard-right">
                  <div className="dashboard">
                    <div className="page-title">
                      <h2>Address</h2>
                      <Button
                        type="link"
                        onClick={() => {
                          setSelectedSchool(null);
                          setUserModel(true);
                        }}
                        style={{ color: "#2E5BA5" }}
                      >
                        <b>Add Address</b>
                      </Button>
                      <Button
                        hidden={!(address.length > 0)}
                        type="link"
                        loading={loading && whatLoading == `remove-all`}
                        onClick={removeAddressAll}
                        style={{ color: "#E52222" }}
                      >
                        <b>Remove All Addresses</b>
                      </Button>
                    </div>
                    {address.length > 0 ? (
                      address?.map((record, i) => (
                        <div className="box">
                          <div key={i} className="box-title">
                            <h3>{"Shipping Address"}</h3>
                          </div>
                          <Row>
                            <Col sm="6">
                              <address>
                                <strong>Company:</strong>{" "}
                                {record.company || " "}
                                <br />
                                <strong>Address line 1:</strong>{" "}
                                {record.address_1 || " "}
                                <br />
                                <strong>Address line 2:</strong>{" "}
                                {record.address_2 || " "}
                                <br />
                                <strong>Country:</strong>{" "}
                                {record.country || " "}
                                <br />
                                <strong>Zip code:</strong>{" "}
                                {record.zip_code || " "}
                                <br />
                                <strong>Phone:</strong> {record.phone || " "}
                                <br />
                                <strong>City:</strong> {record.city || " "}
                                <br />
                                <strong>State:</strong> {record.state || " "}
                              </address>
                              <h6>
                                <Button
                                  type="link"
                                  onClick={() => {
                                    setSelectedSchool(record);
                                    setUserModel(true);
                                  }}
                                  style={{ color: "#2E5BA5" }}
                                >
                                  <b>Update Address</b>
                                </Button>
                                <Button
                                  type="link"
                                  loading={
                                    loading &&
                                    whatLoading == `remove-${record.id}`
                                  }
                                  onClick={() => removeAddress(record.id)}
                                  style={{ color: "#E52222" }}
                                >
                                  <b>Remove Address</b>
                                </Button>
                              </h6>
                            </Col>
                          </Row>
                        </div>
                      ))
                    ) : (
                      <Empty />
                    )}
                  </div>
                </div>
              )}
            </Col>
          </Row>

          {userModel && (
            <Drawer
              open={userModel}
              onClose={() => setUserModel(false)}
              width={600}
            >
              <Form
                layout="vertical"
                size="large"
                form={form}
                onFinish={async (values) => {
                  try {
                    if (!selectedSchool) values.user_id = user.id;
                    const response = await jwtAxios.post(
                      selectedSchool
                        ? `address/update/${selectedSchool?.id}`
                        : `address/create/${user?.id}`,
                      values
                    );
                    console.log(response);

                    fetchAddress();
                    notification.success({
                      message: selectedSchool
                        ? `Address Updated`
                        : `Address Added`,
                      description: selectedSchool
                        ? "Your Address successfully updated"
                        : "Your Address successfully added",
                      placement: "bottomRight",
                    });
                    setSelectedSchool(null);
                    setUserModel(false);
                  } catch (error) {
                    errorHandler(error);
                  }
                }}
              >
                <div className="row check-out">
                  <div className="form-group col-md-12 col-sm-12 col-xs-12">
                    <Form.Item
                      label={"Country"}
                      name="country"
                      rules={[
                        {
                          required: true,
                          message: "Country name is required",
                        },
                      ]}
                      initialValue={"United States"}
                    >
                      <Select
                        className="custom-select"
                        showSearch
                        placeholder={"Select your country"}
                        optionFilterProp="children"
                        filterOption={(input, option) =>
                          option.children
                            .toLowerCase()
                            .indexOf(input.toLowerCase()) >= 0
                        }
                      >
                        {PhoneCodes?.map((country) => (
                          <Select.Option
                            key={country.code}
                            value={country.name}
                          >
                            {country.name}
                          </Select.Option>
                        ))}
                      </Select>
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-6 col-sm-6 col-xs-12">
                    <Form.Item
                      name="first_name"
                      label="First Name"
                      rules={[
                        {
                          required: true,
                          message: "Please input your first name!",
                        },
                      ]}
                    >
                      <Input
                        placeholder="First Name"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-6 col-sm-6 col-xs-12">
                    <Form.Item
                      name="last_name"
                      label=" Last Name"
                      rules={[
                        {
                          required: true,
                          message: "Please input your last name!",
                        },
                      ]}
                    >
                      <Input
                        placeholder="Last Name"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-12 col-sm-12 col-xs-12">
                    <Form.Item name="company" label="Company">
                      <Input
                        placeholder="Company (optional)"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-6 col-sm-6 col-xs-12">
                    <Form.Item
                      rules={[
                        {
                          required: true,
                          message: "Please input zip code!",
                        },
                      ]}
                      name="zip_code"
                      label="Zip Code"
                    >
                      <Input
                        placeholder="Zip Code"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-6 col-sm-6 col-xs-12">
                    <Form.Item
                      rules={[
                        {
                          required: true,
                          message: "Please input your City!",
                        },
                      ]}
                      name="city"
                      label="City"
                    >
                      <Input
                        placeholder="City"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-6 col-sm-6 col-xs-12">
                    <Form.Item
                      rules={[
                        {
                          required: true,
                          message: "Please input your State!",
                        },
                      ]}
                      name="state"
                      label="State"
                    >
                      <Input
                        placeholder="State"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>

                  <div className="form-group col-md-12 col-sm-12 col-xs-12">
                    <Form.Item
                      rules={[
                        {
                          required: true,
                          message: "Please input your phone!",
                        },
                      ]}
                      name="address_1"
                      label="Address line 1"
                    >
                      <Input
                        placeholder="address"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-12 col-sm-12 col-xs-12">
                    <Form.Item name="address_2" label="Address line 2">
                      <Input
                        placeholder="appartment/site/bulding (optional)"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-12 col-sm-12 col-xs-12">
                    <Form.Item
                      rules={[
                        {
                          required: true,
                          message: "Please input your phone!",
                        },
                      ]}
                      name="phone"
                      label="Phone"
                    >
                      <Input
                        placeholder="phone"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group col-md-12 col-sm-12 col-xs-12">
                    <Form.Item
                      name="addressTitle"
                      label="Save address as (optional)"
                    >
                      <Input
                        placeholder="Save address as"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <Form.Item name="save_as">
                    <Checkbox>Save as my default address</Checkbox>
                  </Form.Item>
                </div>

                <Button
                  className="btn btn-solid"
                  htmlType="submit"
                  // loading={whatLoading == "register" && loading}
                >
                  {selectedSchool ? "Update" : "Add New"}
                </Button>
              </Form>
            </Drawer>
          )}
        </Container>
      )}
      {/* </section> */}
    </CommonLayout>
  );
};

export default Dashboard;
