import React, { useState, useEffect } from "react";
import CommonLayout from "../../../components/shop/common-layout";
import { Container, Row, Label, Col } from "reactstrap";
import { useRouter } from "next/router";
import { UserContext } from "../../../helpers/loginContext/loginContext";
import { useContext } from "react";
import Cookie from "js-cookie";
import jwtAxios, { setAuthToken } from "../../../utils/Apis";
import errorHandler from "../../../utils/errorHandler";
import { Button, Divider, Form, Input, notification } from "antd";
import Link from "next/link";
import CartContext from "../../../helpers/cart";
import ReCAPTCHA from "react-google-recaptcha";

const Login = () => {
  const { user, setUser } = useContext(UserContext);
  const context = useContext(CartContext);
  const total = context.cartTotal;
  const [captcha, setCaptcha] = useState(false);
  const [captchaogin, setCaptchaLogin] = useState(false);

  function onCaptchaLogin(value) {
    setCaptchaLogin(!captchaogin);
    console.log("Captcha value:", value);
  }

  function onCaptchaRegister(value) {
    setCaptcha(!captcha);
    console.log("Captcha value:", value);
  }

  const router = useRouter();
  useEffect(() => {
    if (user.id) {
      if (total > 0) router.push("/page/account/checkout");
      else router.push("/");
    }
  }, [user]);
  useEffect(() => {
  if (user.id) {
    if (total > 0) router.push("/page/account/checkout");
    else router.push("/");
  }
  }, []);
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [whatLoading, setWhatLoading] = useState(false);
  const handleSubmit = async (values, route) => {
    setWhatLoading(route);
    setLoading(true);
    try {
      const response = await jwtAxios.post(route, values);
      setLoading(false);

      if (route == "login") {
        console.log("response", route);
        setUser(response.data.user);
        setAuthToken(response.data.token);
        Cookie.set("token", response.data.token);
        Cookie.set("userInfo", JSON.stringify(response.data.user));
        router.back();
        // if (total > 0) router.push("/page/account/checkout");
        // else router.push("/");
      } else {
        notification.success({
          message: `Account Registered`,
          description: "Your account successfully created!",
          placement: "bottomRight",
        });
        form.resetFields();
      }
    } catch (error) {
      errorHandler(error);
      setLoading(false);
    }
  };

  return (
    <CommonLayout parent="home" title="login">
      <section className="login-page section-b-space">
        <Container>
          <Row>
            <Col lg="6">
              <h3>Returning Customer</h3>
              <h6 className="title-font">Welcome Back</h6>
              <div className="theme-card">
                <h3 style={{ color: "#2E5BA5" }}>Login</h3>
                <Divider></Divider>
                <Form
                  layout="vertical"
                  size="large"
                  onFinish={(values) => handleSubmit(values, "login")}
                >
                  <div className="form-group">
                    <Form.Item
                      name="email"
                      label="E-mail"
                      rules={[
                        {
                          type: "email",
                          message: "The input is not valid E-mail!",
                        },
                        {
                          required: true,
                          message: "Please input your E-mail!",
                        },
                      ]}
                    >
                      <Input
                        style={{ borderRadius: "0px" }}
                        placeholder="Email"
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group">
                    <Form.Item
                      name="password"
                      label="Password"
                      rules={[
                        {
                          required: true,
                          message: "Please input your password!",
                        },
                      ]}
                      hasFeedback
                    >
                      <Input.Password placeholder="Password" style={{ borderRadius: "0px" }} />
                    </Form.Item>
                  </div>
                  <div className="form-group">
                    <Form.Item className="form-field">
                      <div
                        className="captcha"
                        style={{
                        width:"100%"
                        }}
                      >
                        <ReCAPTCHA
                          sitekey="6Lc2yzYhAAAAAI_8VOBTUEEKk24dWuIwc351wePj"
                          onChange={onCaptchaLogin}
                        />
                      </div>
                    </Form.Item>
                  </div>
                  <Button
                    disabled={captcha}
                    className="btn btn-solid"
                    loading={whatLoading == "login" && loading}
                    htmlType="submit"
                  >
                    Login
                  </Button>
                  {/* <div className="footer-social">
                    <ul>
                      <li>
                        <a href="https://www.facebook.com" target="_blank">
                          <i className="fa fa-facebook" aria-hidden="true"></i>
                        </a>
                      </li>
                      <li>
                        <a href="https://plus.google.com" target="_blank">
                          <i
                            className="fa fa-google-plus"
                            aria-hidden="true"
                          ></i>
                        </a>
                      </li>
                    </ul>
                  </div> */}
                </Form>
              </div>
            </Col>
            <Col lg="6" className="right-login">
              <h3>New Customer</h3>
              <h6 className="title-font">
                Shopping for your business?{" "}
                <Link
                  href={`/page/account/register`}
                  style={{ fontSize: "14px", color: "#2E5BA5" }}
                >
                  <b> Create a free business account.</b>
                </Link>
              </h6>
              <div className="theme-card authentication-right">
                <h3 style={{ color: "#2E5BA5" }}>Account Registration</h3>
                <Divider></Divider>

                <Form
                  layout="vertical"
                  size="large"
                  onFinish={(values) => handleSubmit(values, "signup")}
                  form={form}
                >
                  <div className="form-group">
                    <Form.Item
                      name="first_name"
                      label="First Name"
                      rules={[
                        {
                          required: true,
                          message: "Please input your first name!",
                        },
                      ]}
                    >
                      <Input
                        placeholder="First Name"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                    <Form.Item
                      name="last_name"
                      label=" Last Name"
                      rules={[
                        {
                          required: true,
                          message: "Please input your last name!",
                        },
                      ]}
                    >
                      <Input
                        placeholder="Last Name"
                        style={{ borderRadius: "0px" }}
                      />
                    </Form.Item>
                  </div>
                  <div className="form-group">
                    <Form.Item
                      name="email"
                      label="E-mail"
                      rules={[
                        {
                          type: "email",
                          message: "The input is not valid E-mail!",
                        },
                        {
                          required: true,
                          message: "Please input your E-mail!",
                        },
                      ]}
                    >
                      <Input
                        style={{ borderRadius: "0px" }}
                        placeholder="Email"

                      />
                    </Form.Item>
                  </div>
                  <div className="form-group">
                    <Form.Item
                      name="password"
                      label="Password"
                     
                      rules={[
                        {
                          required: true,
                          message: "Please input your password!",
                        },
                      ]}
                      hasFeedback
                    >
                      <Input.Password style={{ borderRadius: "0px" }} placeholder="Password" />
                    </Form.Item>
                  </div>
                  <div className="form-group">
                    <Form.Item
                      name="confirm"
                      label="Confirm Password"
                      dependencies={["password"]}
                      hasFeedback
                      rules={[
                        {
                          required: true,
                          message: "Please confirm your password!",
                        },
                        ({ getFieldValue }) => ({
                          validator(_, value) {
                            if (!value || getFieldValue("password") === value) {
                              return Promise.resolve();
                            }
                            return Promise.reject(
                              new Error(
                                "The new password that you entered do not match!"
                              )
                            );
                          },
                        }),
                      ]}
                    >
                      <Input.Password placeholder="Confirm Password" style={{ borderRadius: "0px" }} />
                    </Form.Item>
                  </div>
                  <div className="form-group captcha">
                    <Form.Item className="form-field">
                      <div
                        // className="captcha"
                        // style={{
                        //   transform: "scale(0.92)",
                        //   transformOrigin: "0 0",
                        // }}
                      >
                        <ReCAPTCHA
                          sitekey="6Lc2yzYhAAAAAI_8VOBTUEEKk24dWuIwc351wePj"
                          onChange={onCaptchaRegister}
                        />
                      </div>
                    </Form.Item>
                  </div>
                  <Button
                    className="btn btn-solid"
                    htmlType="submit"
                    disabled={captcha}
                    loading={whatLoading == "register" && loading}
                  >
                    Create an Account
                  </Button>
                </Form>
              </div>
            </Col>
          </Row>
        </Container>
      </section>
    </CommonLayout>
  );
};

export default Login;
