import React, { useState, useEffect } from "react";
import CommonLayout from "../../../components/shop/common-layout";
import { Container, Row, Label, Col } from "reactstrap";
import { useRouter } from "next/router";
import { UserContext } from "../../../helpers/loginContext/loginContext";
import { useContext } from "react";
import { UploadOutlined } from "@ant-design/icons";
import jwtAxios, { API_BASE_URL } from "../../../utils/Apis";
import errorHandler from "../../../utils/errorHandler";
import {
  Button,
  Checkbox,
  DatePicker,
  Divider,
  Form,
  Input,
  Select,
  Upload,
  notification,
} from "antd";
import Link from "next/link";
import PhoneCodes from "../../../components/constant/Codes";
import ReCAPTCHA from "react-google-recaptcha";

const Register = () => {
  const [captchaogin, setCaptchaLogin] = useState(false);

  function onCaptchaLogin(value) {
    setCaptchaLogin(!captchaogin);
    console.log("Captcha value:", value);
  }

  const { user } = useContext(UserContext);
  const normFile = (e) => {
    console.log("Upload event:", e);
    if (Array.isArray(e)) {
      return e;
    }
    console.log("Upload event:", e);
    return e?.fileList;
  };
  const [form] = Form.useForm();
  const router = useRouter();
  useEffect(() => {
    if (user.id) router.push("/");
  }, [user]);
  useEffect(() => {
    if (user.id) router.push("/");
  }, []);
  const [loading, setLoading] = useState(false);
  const [whatLoading, setWhatLoading] = useState(false);
  const handleSubmit = async (values, route) => {
    if (values?.doc1?.length > 0) values.doc1 = values.doc1[0]?.response?.data;
    if (values?.doc2?.length > 0) values.doc2 = values.doc2[0]?.response?.data;
    if (values?.doc3?.length > 0) values.doc3 = values.doc3[0]?.response?.data;
    if (values?.doc4?.length > 0) values.doc4 = values.doc4[0]?.response?.data;
    if (values?.doc5?.length > 0) values.doc5 = values.doc5[0]?.response?.data;
    setWhatLoading(route);
    setLoading(true);
    try {
      const response = await jwtAxios.post(route, values);
      setLoading(false);
      console.log(response);
      // successHandler(response);
      form.resetFields();

      notification.success({
        message: `Account Registered`,
        description: "Your account successfully created!",
        placement: "bottomRight",
      });
      router.push("/page/account/login");
    } catch (error) {
      errorHandler(error);
      setLoading(false);
    }
  };
  const [businessType, setBusinessType] = useState("");

  const handleSelectChange = (value) => {
    setBusinessType(value);
  };

  return (
    <CommonLayout parent="home" title="login">
      <section className="login-page section-b-space">
        <Container>
          <Row>
            <Col lg="12" className="right-login">
              <h3>New Customer</h3>
              <h6 className="title-font">
                Shopping for yourself?{" "}
                <Link href={`/page/account/login`} style={{ fontSize: "14px" }}>
                  <b style={{ color: "#2E5BA5" }}>
                    Create a personal account.
                  </b>
                </Link>
              </h6>
              <div className="theme-card authentication-right">
                <h4 style={{ color: "#2E5BA5" }}>User Information</h4>
                <Divider></Divider>

                <Form
                  layout="vertical"
                  size="large"
                  onFinish={(values) => handleSubmit(values, "bussinessAcct")}
                >
                  <div className="form-group">
                    <Row>
                      <Col lg="4">
                        {" "}
                        <Form.Item
                          name="first_name"
                          label="First Name"
                          rules={[
                            {
                              required: true,
                              message: "Please input your first name!",
                            },
                          ]}
                        >
                          <Input
                            placeholder="First Name"
                            style={{ borderRadius: "0px" }}
                          />
                        </Form.Item>
                      </Col>
                      <Col lg="4">
                        <Form.Item
                          name="last_name"
                          label=" Last Name"
                          rules={[
                            {
                              required: true,
                              message: "Please input your last name!",
                            },
                          ]}
                        >
                          <Input
                            placeholder="Last Name"
                            style={{ borderRadius: "0px" }}
                          />
                        </Form.Item>
                      </Col>

                      <Col lg="4">
                        <Form.Item
                          name="job_title"
                          label=" Job Title:"
                          rules={[
                            {
                              required: true,
                              message: "Please input your Job Title:!",
                            },
                          ]}
                        >
                          <Input
                            placeholder="Job Title"
                            style={{ borderRadius: "0px" }}
                          />
                        </Form.Item>
                      </Col>
                    </Row>
                  </div>
                  <Row>
                    <Col lg="4">
                      <div className="form-group">
                        <Form.Item
                          name="email"
                          label="E-mail"
                          rules={[
                            {
                              type: "email",
                              message: "The input is not valid E-mail!",
                            },
                            {
                              required: true,
                              message: "Please input your E-mail!",
                            },
                          ]}
                        >
                          <Input
                            style={{ borderRadius: "0px" }}
                            placeholder="Email"
                          />
                        </Form.Item>
                      </div>
                    </Col>
                    <Col lg="4">
                      <div className="form-group">
                        <Form.Item
                          name="password"
                          label="Password"
                          rules={[
                            {
                              required: true,
                              message: "Please input your password!",
                            },
                          ]}
                          hasFeedback
                        >
                          <Input.Password style={{ borderRadius: "0px" }} />
                        </Form.Item>
                      </div>
                    </Col>
                    <Col lg="4">
                      <div className="form-group">
                        <Form.Item
                          name="confirm"
                          label="Confirm Password"
                          dependencies={["password"]}
                          hasFeedback
                          rules={[
                            {
                              required: true,
                              message: "Please confirm your password!",
                            },
                            ({ getFieldValue }) => ({
                              validator(_, value) {
                                if (
                                  !value ||
                                  getFieldValue("password") === value
                                ) {
                                  return Promise.resolve();
                                }
                                return Promise.reject(
                                  new Error(
                                    "The new password that you entered do not match!"
                                  )
                                );
                              },
                            }),
                          ]}
                        >
                          <Input.Password style={{ borderRadius: "0px" }} />
                        </Form.Item>
                      </div>
                    </Col>
                  </Row>
                  <h4 style={{ color: "#2E5BA5" }}>Business Information</h4>
                  <Divider></Divider>
                  <Row>
                    <Col lg="4">
                      <Form.Item
                        name="business_name"
                        label="Business Name"
                        rules={[
                          {
                            required: true,
                            message: "Please input your Business Name!",
                          },
                        ]}
                      >
                        <Input
                          placeholder="Business Name"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>

                    <Col lg="4">
                      <Form.Item
                        name="business_phone_number"
                        label="Business Phone Number"
                        rules={[
                          {
                            required: true,
                            message: "Please input your Business Phone Number!",
                          },
                        ]}
                      >
                        <Input
                          placeholder="Business Phone Number"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="Number_employees"
                        label="Number of employees"
                        rules={[
                          {
                            required: true,
                            message: "Please input your Number of employees!",
                          },
                        ]}
                      >
                        <Input
                          placeholder="Number of employees"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                  </Row>
                  <h4 style={{ color: "#2E5BA5" }}>
                    Business Primary Location
                  </h4>
                  <Divider></Divider>
                  <Row>
                    <Col lg="4">
                      <Form.Item
                        label={"Country"}
                        name="Country"
                        rules={[
                          {
                            required: true,
                            message: "Country name is required",
                          },
                        ]}
                        initialValue={"United States"}
                      >
                        <Select
                          style={{ width: "100%" }}
                          showSearch
                          className="custom-select"
                          placeholder={"Select your country"}
                          optionFilterProp="children"
                          filterOption={(input, option) =>
                            option.children
                              .toLowerCase()
                              .indexOf(input.toLowerCase()) >= 0
                          }
                        >
                          {PhoneCodes?.map((country) => (
                            <Select.Option
                              key={country.code}
                              value={country.name}
                            >
                              {country.name}
                            </Select.Option>
                          ))}
                        </Select>
                      </Form.Item>
                    </Col>
                    <Col lg="8">
                      <Form.Item name="Address:" label="Address">
                        <Input
                          placeholder="Address"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>

                    <Col lg="4">
                      <Form.Item
                        name="city"
                        label="City"
                        rules={[
                          {
                            required: true,
                            message: "Please input your City",
                          },
                        ]}
                      >
                        <Input
                          placeholder="City"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="State"
                        label="State"
                        rules={[
                          {
                            required: true,
                            message: "Please input your State",
                          },
                        ]}
                      >
                        <Input
                          placeholder="State"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="zip_code"
                        label="Zip Code"
                        rules={[
                          {
                            required: true,
                            message: "Please input your Zip Code",
                          },
                        ]}
                      >
                        <Input
                          placeholder="Zip Code"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                  </Row>
                  <h4 style={{ color: "#2E5BA5" }}>Digital Presence</h4>
                  <Divider></Divider>
                  <Row>
                    <Col lg="8">
                      <Col lg="12">
                        <Form.Item
                          name="Ecommerce_store_link"
                          label="Ecommerce store link"
                        >
                          <Input
                            placeholder="Ecommerce store link"
                            style={{ borderRadius: "0px" }}
                          />
                        </Form.Item>
                      </Col>
                      <Col lg="12">
                        <Form.Item name="Website_link" label="Website link">
                          <Input
                            placeholder="Website link"
                            style={{ borderRadius: "0px" }}
                          />
                        </Form.Item>
                      </Col>
                    </Col>

                    <Col lg="4">
                      <Form.Item
                        name="Social_media_links"
                        label="Social media links"
                      >
                        <Input.TextArea
                          rows={4}
                          placeholder="Social media links"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                  </Row>
                  <h4 style={{ color: "#2E5BA5" }}>Business Background</h4>
                  <Divider></Divider>
                  <Row>
                    <Col lg="4">
                      <Form.Item
                        name="Date_established"
                        label="Date established"
                        rules={[
                          {
                            required: true,
                            message:
                              "Please input your business Date established!",
                          },
                        ]}
                      >
                        <DatePicker
                          placeholder="Date established"
                          style={{ borderRadius: 0, width: "100%" }}
                        />
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="Form_of_Business"
                        label="Form of Business"
                        rules={[
                          {
                            required: true,
                            message: "Please input your Form of Business!",
                          },
                        ]}
                      >
                        <Select
                          placeholder="Form of Business"
                          style={{ width: "100%" }}
                          className="custom-select"
                        >
                          <Select.Option value="Sole Proprietorship (Single member LLC)">
                            Sole Proprietorship (Single member LLC)
                          </Select.Option>
                          <Select.Option value="Partnership">
                            Partnership
                          </Select.Option>
                          <Select.Option value="Corporation">
                            Corporation
                          </Select.Option>
                        </Select>
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="sales_volume"
                        label="Annual sales volume"
                        rules={[
                          {
                            required: true,
                            message: "Please input your Annual sales volume !",
                          },
                        ]}
                      >
                        <Select
                          placeholder="Annual sales volume "
                          style={{ width: "100%" }}
                          className="custom-select"
                        >
                          <Select.Option value="Less than $12,000">
                            Less than $12,000
                          </Select.Option>
                          <Select.Option value="$12,000 - $99,999 ">
                            $12,000 - $99,999
                          </Select.Option>
                          <Select.Option value="$100,000 - $249,999">
                            $100,000 - $249,999
                          </Select.Option>
                          <Select.Option value="$250,000 - $499,999">
                            $250,000 - $499,999
                          </Select.Option>
                          <Select.Option value="$500,000 -$999,999">
                            $500,000 -$999,999
                          </Select.Option>
                          <Select.Option value="$1,000,000 +">
                            $1,000,000 +
                          </Select.Option>
                        </Select>
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="business_type"
                        label="Business Type"
                        rules={[
                          {
                            required: true,
                            message: "Please input your Business Type!",
                          },
                        ]}
                      >
                        <Select
                          placeholder="Select business type"
                          onChange={handleSelectChange}
                          style={{ width: "100%" }}
                          className="custom-select"
                        >
                          <Option value="autoPartsChain">
                            Auto parts chain
                          </Option>
                          <Option value="autoPartsStore">
                            Auto parts store
                          </Option>
                          <Option value="ecommerce">Ecommerce</Option>
                          <Option value="engineBuilder">Engine builder</Option>
                          <Option value="exporter">Exporter</Option>
                          <Option value="generalRepair">General repair</Option>
                          <Option value="installer">Installer</Option>
                          <Option value="manufacturer">Manufacturer</Option>
                          <Option value="carDealership">Car dealership</Option>
                          <Option value="restorationCenter">
                            Restoration Center
                          </Option>
                          <Option value="tuningShop">Tuning Shop</Option>
                          <Option value="wheelAndTire">Wheel and tire</Option>
                          <Option value="wholesaleDistributor">
                            Wholesale distributor
                          </Option>
                          <Option value="other">Other</Option>
                        </Select>
                      </Form.Item>
                    </Col>

                    {businessType === "other" && (
                      <Col lg="4">
                        <Form.Item
                          name="business_type_other"
                          label="Specify the Business Type"
                          rules={[
                            {
                              required: true,
                              message: "Please input your business_type_other!",
                            },
                          ]}
                        >
                          <Input
                            placeholder="Specify the Business Type"
                            style={{ borderRadius: "0px" }}
                          />
                        </Form.Item>
                      </Col>
                    )}
                  </Row>

                  <h4 style={{ color: "#2E5BA5" }}>Owner/Partner</h4>
                  <Divider></Divider>
                  <Row>
                    <Col lg="12">
                      <Form.Item name="Shipping_Terms" label="Shipping Terms">
                        <Input.TextArea
                          placeholder="Shipping Terms"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                    <Col lg="12">
                      <Form.Item name="Return_Policy" label="Return Policy">
                        <Input.TextArea
                          placeholder="Return Policy"
                          style={{ borderRadius: "0px" }}
                        />
                      </Form.Item>
                    </Col>
                  </Row>
                  <h4 style={{ color: "#2E5BA5" }}>
                    Business Documents/ Attachments
                  </h4>
                  <Divider></Divider>
                  <Row>
                    <Col lg="4">
                      <Form.Item
                        name="doc1"
                        label="Document 1"
                        valuePropName="fileList"
                        getValueFromEvent={normFile}
                      >
                        <Upload
                          name="file"
                          action={`${API_BASE_URL}documents`}
                          maxCount={1}
                          // listType="picture"
                        >
                          <Button icon={<UploadOutlined />}>
                            Click to Upload
                          </Button>
                        </Upload>
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="doc2"
                        label="Document 2"
                        valuePropName="fileList"
                        getValueFromEvent={normFile}
                      >
                        <Upload
                          name="file"
                          action={`${API_BASE_URL}documents`}
                          maxCount={1}
                          // listType="picture"
                        >
                          <Button icon={<UploadOutlined />}>
                            Click to Upload
                          </Button>
                        </Upload>
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="doc3"
                        label="Document 3"
                        valuePropName="fileList"
                        getValueFromEvent={normFile}
                      >
                        <Upload
                          name="file"
                          action={`${API_BASE_URL}documents`}
                          maxCount={1}
                          // listType="picture"
                        >
                          <Button icon={<UploadOutlined />}>
                            Click to Upload
                          </Button>
                        </Upload>
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="doc4"
                        label="Document 4"
                        valuePropName="fileList"
                        getValueFromEvent={normFile}
                      >
                        <Upload
                          name="file"
                          action={`${API_BASE_URL}documents`}
                          maxCount={1}
                          // listType="picture"
                        >
                          <Button icon={<UploadOutlined />}>
                            Click to Upload
                          </Button>
                        </Upload>
                      </Form.Item>
                    </Col>
                    <Col lg="4">
                      <Form.Item
                        name="doc5"
                        label="Document 5"
                        valuePropName="fileList"
                        getValueFromEvent={normFile}
                      >
                        <Upload
                          name="file"
                          action={`${API_BASE_URL}documents`}
                          maxCount={1}
                          // listType="picture"
                        >
                          <Button icon={<UploadOutlined />}>
                            Click to Upload
                          </Button>
                        </Upload>
                      </Form.Item>
                    </Col>
                  </Row>
                  <Form.Item
                    name="checkBox"
                    valuePropName="checked"
                    rules={[
                      {
                        validator: (_, value) =>
                          value
                            ? Promise.resolve()
                            : Promise.reject(
                                new Error(
                                  " Terms and Condition should be checked"
                                )
                              ),
                      },
                    ]}
                  >
                    <Checkbox>
                      I accept the{" "}
                      <a href="/shop/privacy-policy">
                        Privacy Policy, Term & Conditions
                      </a>
                    </Checkbox>
                  </Form.Item>
                  <div className="form-group">
                    <Form.Item className="form-field">
                      <div
                        className="captcha"
                        style={{
                          transform: "scale(0.92)",
                          transformOrigin: "0 0",
                        }}
                      >
                        <ReCAPTCHA
                          sitekey="6Lc2yzYhAAAAAI_8VOBTUEEKk24dWuIwc351wePj"
                          onChange={onCaptchaLogin}
                        />
                      </div>
                    </Form.Item>
                  </div>

                  <Button
                    className="btn btn-solid"
                    htmlType="submit"
                    style={{ borderRadius: "0px" }}
                    loading={whatLoading == "register" && loading}
                  >
                    Create an Account
                  </Button>
                </Form>
              </div>
            </Col>
          </Row>
        </Container>
      </section>
    </CommonLayout>
  );
};

export default Register;
