import React from "react";
import CommonLayout from "../../components/shop/common-layout";
import { Container, Row, Col, Media, Label } from "reactstrap";
import { Button, Form, Input, message } from "antd";
import jwtAxios from "../../utils/Apis";
import errorHandler from "../../utils/errorHandler";

const Data = [
  {
    img: "fa-map-marker",
    title: "Office Address",
    desc1: "ABC Complex,Near xyz, New York",
    desc2: "USA 123456",
    color: "#8ffa31",
  },
  {
    img: "fa-phone",
    title: "Phone Number",
    // desc1: "+44 300 - 272 - 4455",
    desc1: "+86 163 - 451 - 7894",
    color: "purple",
  },

  {
    img: "fa-envelope-o",
    title: "Send Email",
    desc1: "support@example.pk",
    // desc2: "info@shopcart.com",
    color: "orange",
  },
];

const ContactDetail = ({ img, title, desc1, desc2, color }) => {
  return (
    <div style={{ marginBottom: "30px" }}>
      <div className="contact-icon">
        <i
          className={`fa ${img} faicon`}
          aria-hidden="true"
          // style={{ color: color }}
        ></i>
        <h6 className="contitle">{title}</h6>
      </div>
      <div className="media-body">
        <p>{desc1}</p>
        {/* <p>{desc2}</p> */}
      </div>
    </div>
  );
};
const Contact = () => {
  const [form] = Form.useForm();
  return (
    <CommonLayout parent="home" title="Contact">
      <section
        className="contact-page section-b-space"
        // style={{ backgroundColor: "#fffaeb" }}
      >
        <Container className="leftcontact">
          <Row
            className="section-b-space"
            style={{
              paddingBottom: "0px",
              display: "flex",
              alignItems: "center",
            }}
          >
            <Col
              md="4"
              style={{
                display: "flex",
                flexDirection: "column",
                justifyContent: "space-between",
                alignItems: "center",
                textAlign: "center",
              }}
            >
              {/* <div className="contactright"> */}
              {/*<ul> */}
              {Data.map((data, i) => {
                return (
                  <ContactDetail
                    key={i}
                    img={data.img}
                    color={data.color}
                    title={data.title}
                    desc1={data.desc1}
                    desc2={data.desc2}
                  />
                );
              })}
              {/* </ul> */}
              {/* </div>  */}
            </Col>
            <Col md="8">
              <Form
                form={form}
                className="theme-form"
                onFinish={async (values) => {
                  try {
                    const response = await jwtAxios.post("contact/email", values);
                    message.success("Message Send Successfully");
                    form.resetFields();
                  } catch (error) {
                    errorHandler(error);
                  }
                }}
              >
                <Row>
                  <h3
                    style={{
                      textAlign: "center",
                      paddingBottom: "20px",
                      color: "black",
                    }}
                  >
                    Leave us a message
                  </h3>
                </Row>
                <Row>
                  <Col md="6">
                    {/* <Label className="form-label" for="name">First Name</Label> */}
                    <Form.Item
                      name={"name"}
                      rules={[
                        {
                          required: true,
                          message: "please Input your good name ",
                        },
                      ]}
                    >
                      <Input
                        type="text"
                        className="form-control contactfield"
                        id="name"
                        placeholder="Enter Your name"
                        required=""
                      />
                    </Form.Item>
                  </Col>
                  <Col md="6">
                    <Form.Item
                      name={"email"}
                      rules={[
                        {
                          required: true,
                          message: "please Input email",
                        },
                        { type: "email" },
                      ]}
                    >
                      <Input
                        type="email"
                        className="form-control contactfield"
                        id="last-name"
                        placeholder="Email"
                        required=""
                      />
                    </Form.Item>
                  </Col>
                </Row>
                {/* <Row>
                  <Col md="6">
                    <Label className="form-label" for="review">Phone number</Label>
                    <Input
                      type="text"
                      className="form-control contactfield"
                      id="review"
                      placeholder="Enter your number"
                      required=""
                    />
                  </Col>
                  <Col md="6">
                    <Label className="form-label" for="email">Email</Label>
                    <Input
                      type="email"
                      className="form-control contactfield"
                      id="email"
                      placeholder="Email"
                      required=""
                    />
                  </Col>
                </Row> */}
                <Row style={{ textAlign: "center" }}>
                  <Col md="12">
                    <Form.Item name={"message"}>
                      <Input.TextArea
                        className="form-control"
                        placeholder="Write Your Message"
                        id="exampleFormControlTextarea1"
                        rows="6"
                      ></Input.TextArea>
                    </Form.Item>
                  </Col>
                  <Col md="12">
                    <Button
                      className="btn btn-solid contactbtn"
                      type="submit"
                      htmlType="submit"
                      style={{ paddingBottom: "30px" }}
                    >
                      Send Message
                    </Button>
                  </Col>
                </Row>
              </Form>
            </Col>
          </Row>
        </Container>
        {/* <Container>
          <Row>

            <Col lg="7" className="map">
              <iframe
                src="https://www.google.com/maps/embed?pb=!1m14!1m12!1m3!1d1605.811957341231!2d25.45976406005396!3d36.3940974010114!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!5e0!3m2!1sen!2sin!4v1550912388321"
                allowFullScreen
              ></iframe>
            </Col>
          </Row>
        </Container> */}
      </section>
    </CommonLayout>
  );
};

export default Contact;
